;;; A Common Lisp implementation of the compo protocol Version 2
;;;
;;; Package :compo-cm
;;;
;;; Copyright (C) 2001  Bruno LARTILLOT
;;; 
;;; This program is free software; you can redistribute it and/or
;;; modify it under the terms of the GNU General Public License
;;; as published by the Free Software Foundation; either version 2
;;; of the License, or any later version.
;;;
;;; This program is distributed in the hope that it will be useful,
;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
;;; along with this program; if not, write to the Free Software
;;; Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

(in-package :compo-cm)

(let ((ass `((,#'(lambda (x) (naturalp x :syntax :english)) . cmn::natural)
             (,#'(lambda (x) (sharpp x :syntax :english)) . cmn::sharp)
             (,#'(lambda (x) (double-sharp-p x :syntax :english)) . cmn::double-sharp)
             (,#'(lambda (x) (flatp x :syntax :english)) . cmn::flat)
             (,#'(lambda (x) (double-flat-p x :syntax :english)) . cmn::double-flat) ) ))

  (defun conv-pitch (pitch oct tone)
    (let* ((norm (itp (- (pti pitch :syntax :english) tone) :syntax :english))
           (str (symbol-name pitch))
           (char (elt str 0))
           (name (make-string 1 :initial-element char))
           (alt (if (naturalp norm :syntax :english) 
                  nil
                  (cdr
                   (assoc-if #'(lambda (k)
                                 (funcall k pitch) )
                           ass ) ) ))
           (stream (make-string-output-stream)) )
      (when (and (equal name "C")(or (flatp pitch)(double-flat-p pitch)))
        (incf oct) )
      (when (and (equal name "B")(or (sharpp pitch)(double-sharp-p pitch)))
        (decf oct) )
      (write oct :stream stream)
      (list (read (make-string-input-stream
                   (concatenate 'string
                                "cmn::"
                                name
                                (get-output-stream-string stream) ) ))
            alt ) ) ) )

(defun y-lyrics (mark note score &optional justifying)
  (declare (ignore mark score justifying))
  (- (cmn::staff-y0 note) .7) )

(defun y-lyrics-2 (mark note score &optional justifying)
  (declare (ignore mark score justifying))
  (- (cmn::staff-y0 note) 1.2) )

(let ((tones (pairlis
              `((:C :major-mode)
                (:A :minor-mode)
                (:CS :major-mode)
                (:AS :minor-mode)
                (:DF :major-mode)
                (:BF :minor-mode)
                (:D :major-mode)
                (:B :minor-mode)
                (:EF :major-mode)
                (:C :minor-mode)
                (:E :major-mode)
                (:CS :minor-mode)
                (:F :major-mode)
                (:D :minor-mode)
                (:FS :major-mode)
                (:DS :minor-mode)
                (:GF :major-mode)
                (:EF :minor-mode)
                (:G :major-mode)
                (:E :minor-mode)
                (:AF :major-mode)
                (:F :minor-mode)
                (:A :major-mode)
                (:FS :minor-mode)
                (:BF :major-mode)
                (:G :minor-mode)
                (:B :major-mode)
                (:GS :minor-mode)
                (:CF :major-mode)
                (:AF :minor-mode) )

              '(cmn::c-major cmn::a-minor cmn::cs-major
                cmn::as-minor cmn::df-major cmn::bf-minor 
                cmn::d-major cmn::b-minor cmn::ef-major
                cmn::c-minor cmn::e-major cmn::cs-minor 
                cmn::f-major cmn::d-minor cmn::fs-major
                cmn::ds-minor cmn::gf-major cmn::ef-minor 
                cmn::g-major cmn::e-minor cmn::af-major
                cmn::f-minor cmn::a-major cmn::fs-minor 
                cmn::bf-major cmn::g-minor cmn::b-major
                cmn::gs-minor cmn::cf-major cmn::af-minor ) )) )
  
  (labels ((separ (subs voi resa)
             (if (or (atom subs) (/= (voi (car subs)) voi))
               (cons resa subs)
               (separ (cdr subs) voi (append resa `(,(car subs)))) ) )

           (compl (part pos tot-dur)
             (if (not part)
               (and (< pos tot-dur)
                    (list (make-instance
                            'note
                            :hei nil
                            :pos tot-dur )) )
               (cons (car part)
                     (compl (cdr part)
                            (+ (pos (car part)) (dur (car part)))
                            tot-dur ) ) ) )

           (parts (subs tot-dur)
             (and (consp subs)
                  ((lambda (res) (cons (compl (car res) 0 tot-dur)
                                       (parts (cdr res) tot-dur) ))
                   (separ subs (voi (car subs)) nil) ) ) )

           (cmnize-item (note key lyr1 lyr2)
             (unless (name note)
               (multiple-value-bind (i o) (itei (hei note))
                 (setf i (itp i :syntax :english))
                 (list
                  (append 
                   (if i
                     (conv-pitch i o key)
                     (list
                      (case (dur note)
                        ((8) 'cmn::double-whole-rest)
                        ((4) 'cmn::whole-rest)
                        ((6) 'cmn::dotted-whole-rest)
                        ((2) 'cmn::half-rest)
                        ((3) 'cmn::dotted-half-rest)
                        ((1) 'cmn::quarter-rest)
                        ((3/2) 'cmn::dotted-quarter-rest)
                        ((1/2) 'cmn::eighth-rest)
                        ((3/4) 'cmn::dotted-eighth-rest)
                        ((1/4) 'cmn::sixteenth-rest)
                        ((3/8) 'cmn::dotted-sixteenth-rest)
                        ((1/8) 'cmn::thirty-second-rest)
                        ((1/16) 'cmn::sixty-fourth-rest)
                        ((1/32) 'cmn::one-twenty-eighth-rest) ) ) )
                   (when (typep note 'fermata)
                     '(cmn::fermata) )
                   (when lyr1
                     `((cmn::text ,(name (car lyr1))
                                  (cmn::y #'y-lyrics)
                                  (cmn::font-size ,(floor *default-size* 2)) )) )
                   (when lyr2
                     `((cmn::text ,(name (car lyr2))
                                  (cmn::y #'y-lyrics-2)
                                  (cmn::font-size ,(floor *default-size* 2)) )) )
                   (list (list 'cmn::onset (pos note))
                         (and i (list 'cmn::duration (dur note)) ) ) ) ) ) ) )

           (process-part (part key key-sign time tied-voices)
             (multiple-value-bind (r q) (ntoev (voi (car part)))
               (let* ((tmp (find-if #'(lambda (x) (eql r (cton (car x))))
                                    tied-voices ))
                      (sym (and tmp (or (cdr tmp) (gensym))))
                      (stem (and tmp (if (evenp q) 'cmn::stem-up 'cmn::stem-down)))
                      (res
                       (append
                        (list 'cmn::staff 'cmn::bar)
                        ((lambda (x) (and x `(,x)))
                         (elt *voices* (mod (- (voi (car part))) 16)) )
                        key-sign
                        ((lambda (x) (and x `(,x)))
                         (cond
                          ((numberp time)
                           `(cmn::meter ,time 4) )
                          ((atom time)
                           `(cmn::meter ,time) )
                          ((listp time)
                           `(cmn::meter ,@time) ) ) )
                        (labels ((f (x)
                                   (and x
                                        (let* ((restx (h x x))
                                               (subx (ldiff x restx))
                                               (lyr2 (g subx))
                                               (lyr1 (and lyr2 (g (cdr lyr2)))) )
                                          (unless lyr1 (setf lyr1 lyr2) (setf lyr2 nil))
                                          (append
                                           (if (hei (car subx))
                                             ((lambda (z)
                                                (and z
                                                     (list
                                                      (append (if stem
                                                                (list 'cmn::chord stem)
                                                                (list 'cmn::chord) )
                                                              z ) ) ) )
                                              (mapcan #'(lambda (y)
                                                                     (cmnize-item y key lyr1 lyr2))
                                                                 subx ) )
                                             (cmnize-item (car subx) key lyr1 lyr2) )
                                           (f restx) ) ) ) )
                                 (g (y)
                                   (and y
                                        (if (name (car y))
                                          y
                                          (g (cdr y)) ) ) )
                                 (h (y lis)
                                   (and y
                                        (if (not (eql (pos (car y)) (pos (car lis))))
                                          y
                                          (h (cdr y) lis) ) ) ) )
                          (f part) )
                        (list 'cmn::double-bar) ) ) )
                 (if tmp
                   (if (cdr tmp)
                     (progn (setf (cdr res) (cons `(cmn::tied-to ,sym) (cdr res))) res)
                     (progn (setf (cdr tmp) sym) (append `(setf ,sym) (list res))) )
                   res ) ) ) ) )

    (defun cmnize (note
                   &key (mode *default-mode*)
                        (key *default-key*)
                        (time *default-time*)
                        (output-type cmn::*cmn-output-type*)
                        (output-file *default-output-file*)
                        (size *default-size*)
                        (free-expansion-factor *default-free-expansion-factor*)
                        (staff-separation *default-staff-separation*)
                        (line-separation *default-line-separation*)
                        (initial-onset 0)
                        tied-voices )

"Funtion
   cmnize (note &key :mode
                     :key
                     :time
                     :output-type
                     :output-file
                     :size
                     :free-expansion-factor
                     :staff-separation
                     :line-separation
                     :initial-onset
                     :tied-voices)
Arguments
   A normalized (realized with the context 'standard-context') note structure.
   A mode being one of the two keywords :major-mode or :minor-mode, defaulting to
   the current value of the special variable *default-mode*.
   A key value among the keywords :C :D :E :F :G :A :B :CS :DS :FS :GS :AS :CF :DF :EF
   :GF :AF and :BF, defaulting to the current value of the special variable
   *default-key*.
   A time being either :
   . A number : in this case, the time signature is considered to be number/4
     (for example 3/4 if the number is 3);
   . A symbol which can be 'cmn::alla-breve', 'cmn::common-time', 'cmn::cut-time' or
     'cmn::unmetered';
   . A list of two numbers (for example '(3 8)' for a time signature of 3/8.
   The time defaults to the current value of the special variable *default-time*.
   An output type which schould complies to those of the package :cmn (see Common Music
   Notation from the CCRMA), and defaulting to the current value of the special variable
   'cmn::*cmn-output-type*'.
   A pathname designing the output file to be produced, defaulting to the current value
   of the special variable *default-output-file*.
   A size defaulting to the current value of the special variable *default-size* (see
   Common Music Notation).
   A free expansion factor defaulting to the current value of the special variable
   *default-free-expansion-factor* (see Common Music Notation).
   A staff separation value defaulting to the current value of the special variable
   *default-staff-separation* (see Common Music Notation).
   A line separation value defaulting to the current value of the special variable
   *default-line-separation* (see Common Music Notation).
   An initial onset defaulting to 0.
   The list of the voice classes to be tied defaulting to the empty list.
Values
   No value is returned.
   As a side effect, a Common Music Notation form representing the normalized note
   structure, with one staff per different voice value found in the elementary notes,
   is produced."

  (setf tied-voices (mapcar #'(lambda (x) (list x)) tied-voices))
  (and (subs note)
       output-type
       ((lambda (x)
          (append `(cmn::cmn (cmn::size ,size)
                             (cmn::output-type ,output-type)
                             (cmn::output-file ,(namestring output-file))
                             (cmn::free-expansion-factor ,free-expansion-factor)
                             (cmn::staff-separation ,staff-separation)
                             (cmn::line-separation ,line-separation)
                             (cmn::automatic-naturals t)
                             (cmn::implicit-accidental-style :old-style)
                             (cmn::redundant-accidentals nil)
                             (cmn::initial-onset ,initial-onset) )
                  (if (= (length x) 1)
                    '(cmn::system)
                    (if (> (length x) 2)
                      '(cmn::system cmn::bracket)
                      '(cmn::system cmn::brace) ) )
                  (mapcon #'(lambda (sub)
                              ((lambda (x)
                                 (list (process-part
                                        (car sub)
                                        (pti key :syntax :english)
                                        (and x `(,(cdr x)))
                                        time
                                        tied-voices ) ) )
                               (assoc-if #'(lambda (k)
                                             (and (eq key (first k))
                                                  (eq mode (second k))) )
                                         tones ) ) )
                          x ) ) )
        (parts
         (sort (copy-list (subs note))
               #'(lambda (x y)
                   (let ((evx (ntoev (voi x)))
                         (evy (ntoev (voi y))) )
                     (if
                       (or (> evx evy)
                           (and (= evx evy)
                                (> (voi x) (voi y)) )
                           (and (= (voi x) (voi y))
                                (< (pos x) (pos y)) )
                           (and (= (voi x) (voi y))
                                (= (pos x) (pos y))
                                (< (hei x) (hei y)) ) )
                       x
                       nil ) ) ) )
         (+ (pos note) (dur note)) ) ) ) ) ) )