;;; A Common Lisp implementation of the compo protocol Version 2
;;;
;;; Package :compo-cm
;;;
;;; Copyright (C) 2001  Bruno LARTILLOT
;;; 
;;; This program is free software; you can redistribute it and/or
;;; modify it under the terms of the GNU General Public License
;;; as published by the Free Software Foundation; either version 2
;;; of the License, or any later version.
;;;
;;; This program is distributed in the hope that it will be useful,
;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
;;; along with this program; if not, write to the Free Software
;;; Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

(in-package :compo-cm)

(proclaim '(special *test-result*))

(setf *test-result* t)

(setf *bwv244* 
      (note "BWV 244 - Herzliebster Jesu" :pos 3
       lyrics=(("Herz-")("lieb-")("ster")("Je-")("su,")("was")("hast")("du")("ver-")("bro" :h)("chen,")
               ("dass")("man")("ein")("solch")("scharf")("Ur-")("teil")("hat")("ge-")("spro-" :h)("chen?")
               ("Was")("ist")("die")("Schuld,")("in")("was")("fuer")("Mis-")("se-")("ta-" :h)("ten")
               ("bist")("du")("ge-")("ra-" :h)("ten?" :h.))
       (lyrics :soprano :super lyrics)
       (lyrics :tenor :super lyrics)

       (:soprano :super
        (:b)(:b)(:b)(:as :8th)(:gs :8th)(:fs)(:b)(:cs5)(:d5)(:d5)(:e5)(:d5)(fermata :cs5)
        (:cs5)(:d5)(:e5)(:fs5 :8th)(:e5 :8th)(:d5)(:g5)(:g5)(:fs5 :8th)(:e5 :8th)(:fs5)(:e5 :h)(fermata :d5)
        (:d5)(:cs5)(:b)(:a)(:fs :8th)(:g :8th)(:a)(:a)(:b)(:a)(:g :h)(fermata :fs)
        (:fs5)(:e5)(:d5)(:cs5 :h)(fermata :b :h.))

       (:alto :super
        (:fs)(:g)(:d :8th)(:e :8th)(:fs)(:cs)(:fs)(:fs)(:fs)(:fs)(:fs :h)(fermata :fs)
        (:fs)(:fs)(:a)(:a)(:b :8th)(:a :8th)(:g)(:a)(:a)(:d5 :8th)(:cs5 :8th)(:b)(:a :8th)(:g :8th)(fermata :fs)
        (:fs)(:e)(:d)(:e)(:d :8th)(:e :8th)(:fs)(:fs)(:g)(:fs)(:fs :8th)(:ds :8th)(:e)(fermata :e)
        (:d)(:g)(:fs)(:fs :q.)(:e :8th)(fermata :ds :h.))

       (:tenor :c3 :super
        (:d5)(:e5)(:b)(:cs5 :8th)(:b :8th)(:as)(:b)(:as)(:b :8th)(:cs5 :8th)(:d5)(:cs5)(:b)(fermata :as)
        (:as)(:b)(:cs5)(:d5 :8th)(:cs5 :8th)(:b :8th)(:cs5 :8th)(:d5)(:e5)(:e5)(:d5)(:d5)(:cs5)(fermata :a)
        (:b :8th)(:a :8th)(:g)(:g :8th)(:fs :8th)(:e :8th)(:a :8th)(:a)(:d5)(:d5)(:d5)(:c5)(:b :q.)(:as :16th)(:b :16th)(fermata :cs5)
        (:b)(:b :8th)(:as :8th)(:b)(:b)(:as)(fermata :fs :h.))

       (:bass :c3 :super
        (:b)(:e :8th)(:fs :8th)(:g)(:fs)(:fs :8th)(:e :8th)(:d)(:fs)(:b3)(:b)(:as)(:b)(fermata :fs)
        (:fs)(:b)(:a)(:d)(:g :8th)(:a :8th)(:b)(:cs5)(:d5 :8th)(:cs5 :8th)(:b :8th)(:a :8th)(:g)(:a)(fermata :d)
        (:b3)(:e :8th)(:fs :8th)(:g)(:cs)(:d)(:d5 :8th)(:c5 :8th)(:b :8th)(:a :8th)(:g :8th)(:fs :8th)(:e :8th)(:ds :8th)(:e :h)(fermata :as3)
        (:b3)(:cs)(:d :8th)(:e :8th)(:fs :h)(fermata :b3 :h.))))

;;; test of the cmnize function

(cleave-change :soprano 'cmn::treble)
(cleave-change :alto 'cmn::treble)
(cleave-change :tenor 'cmn::tenor-treble)

(when (not (is-equal
            (cmnize
             (realize *bwv244* :preserve-lyrics t)
             :key :d
             :size 24
             :free-expansion-factor 1.5
             :staff-separation 2
             :line-separation 3)
            `(CMN::CMN (CMN::SIZE 24)
                       (CMN::OUTPUT-TYPE ,cmn::*cmn-output-type*)
                       (CMN::OUTPUT-FILE ,(namestring *default-output-file*))
                       (CMN::FREE-EXPANSION-FACTOR 1.5)
                       (CMN::STAFF-SEPARATION 2)
                       (CMN::LINE-SEPARATION 3)
                       (CMN::AUTOMATIC-NATURALS T)
                       (CMN::IMPLICIT-ACCIDENTAL-STYLE :OLD-STYLE)
                       (CMN::REDUNDANT-ACCIDENTALS NIL)
                       (CMN::INITIAL-ONSET 0)
                       CMN::SYSTEM
                       CMN::BRACKET
                       (CMN::STAFF CMN::BAR
                                   CMN::TREBLE
                                   CMN::D-MAJOR
                                   (CMN::METER CMN::COMMON-TIME)
                                   (CMN::CHORD (CMN::B4 NIL (CMN::TEXT "Herz-" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 3) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::B4 NIL (CMN::TEXT "lieb-" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 4) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::B4 NIL (CMN::TEXT "ster" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 5) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::A4 CMN::SHARP (CMN::TEXT "Je-" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 6) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::G4 CMN::SHARP (CMN::ONSET 13/2) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::F4 NIL (CMN::TEXT "su," (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 7) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::B4 NIL (CMN::TEXT "was" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 8) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::C5 NIL (CMN::TEXT "hast" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 9) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::D5 NIL (CMN::TEXT "du" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 10) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::D5 NIL (CMN::TEXT "ver-" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 11) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::E5 NIL (CMN::TEXT "bro" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 12) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::D5 NIL (CMN::ONSET 13) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::C5 NIL CMN::FERMATA (CMN::TEXT "chen," (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 14) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::C5 NIL (CMN::TEXT "dass" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 15) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::D5 NIL (CMN::TEXT "man" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 16) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::E5 NIL (CMN::TEXT "ein" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 17) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::F5 NIL (CMN::TEXT "solch" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 18) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::E5 NIL (CMN::ONSET 37/2) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::D5 NIL (CMN::TEXT "scharf" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 19) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::G5 NIL (CMN::TEXT "Ur-" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 20) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::G5 NIL (CMN::TEXT "teil" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 21) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::F5 NIL (CMN::TEXT "hat" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 22) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::E5 NIL (CMN::ONSET 45/2) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::F5 NIL (CMN::TEXT "ge-" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 23) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::E5 NIL (CMN::TEXT "spro-" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 24) (CMN::DURATION 2)))
                                   (CMN::CHORD (CMN::D5 NIL CMN::FERMATA (CMN::TEXT "chen?" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 26) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::D5 NIL (CMN::TEXT "Was" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 27) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::C5 NIL (CMN::TEXT "ist" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 28) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::B4 NIL (CMN::TEXT "die" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 29) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::A4 NIL (CMN::TEXT "Schuld," (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 30) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::F4 NIL (CMN::TEXT "in" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 31) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::G4 NIL (CMN::ONSET 63/2) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::A4 NIL (CMN::TEXT "was" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 32) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::A4 NIL (CMN::TEXT "fuer" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 33) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::B4 NIL (CMN::TEXT "Mis-" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 34) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::A4 NIL (CMN::TEXT "se-" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 35) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::G4 NIL (CMN::TEXT "ta-" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 36) (CMN::DURATION 2)))
                                   (CMN::CHORD (CMN::F4 NIL CMN::FERMATA (CMN::TEXT "ten" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 38) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::F5 NIL (CMN::TEXT "bist" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 39) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::E5 NIL (CMN::TEXT "du" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 40) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::D5 NIL (CMN::TEXT "ge-" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 41) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::C5 NIL (CMN::TEXT "ra-" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 42) (CMN::DURATION 2)))
                                   (CMN::CHORD (CMN::B4 NIL CMN::FERMATA (CMN::TEXT "ten?" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 44) (CMN::DURATION 3)))
                                   CMN::DOUBLE-BAR)
                       (CMN::STAFF CMN::BAR
                                   CMN::TREBLE
                                   CMN::D-MAJOR
                                   (CMN::METER CMN::COMMON-TIME)
                                   (CMN::CHORD (CMN::F4 NIL (CMN::ONSET 3) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::G4 NIL (CMN::ONSET 4) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::D4 NIL (CMN::ONSET 5) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::E4 NIL (CMN::ONSET 11/2) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::F4 NIL (CMN::ONSET 6) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::C4 NIL (CMN::ONSET 7) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::F4 NIL (CMN::ONSET 8) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::F4 NIL (CMN::ONSET 9) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::F4 NIL (CMN::ONSET 10) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::F4 NIL (CMN::ONSET 11) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::F4 NIL (CMN::ONSET 12) (CMN::DURATION 2)))
                                   (CMN::CHORD (CMN::F4 NIL CMN::FERMATA (CMN::ONSET 14) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::F4 NIL (CMN::ONSET 15) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::F4 NIL (CMN::ONSET 16) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::A4 NIL (CMN::ONSET 17) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::A4 NIL (CMN::ONSET 18) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::B4 NIL (CMN::ONSET 19) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::A4 NIL (CMN::ONSET 39/2) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::G4 NIL (CMN::ONSET 20) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::A4 NIL (CMN::ONSET 21) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::A4 NIL (CMN::ONSET 22) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::D5 NIL (CMN::ONSET 23) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::C5 NIL (CMN::ONSET 47/2) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::B4 NIL (CMN::ONSET 24) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::A4 NIL (CMN::ONSET 25) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::G4 NIL (CMN::ONSET 51/2) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::F4 NIL CMN::FERMATA (CMN::ONSET 26) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::F4 NIL (CMN::ONSET 27) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::E4 NIL (CMN::ONSET 28) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::D4 NIL (CMN::ONSET 29) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::E4 NIL (CMN::ONSET 30) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::D4 NIL (CMN::ONSET 31) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::E4 NIL (CMN::ONSET 63/2) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::F4 NIL (CMN::ONSET 32) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::F4 NIL (CMN::ONSET 33) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::G4 NIL (CMN::ONSET 34) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::F4 NIL (CMN::ONSET 35) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::F4 NIL (CMN::ONSET 36) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::D4 CMN::SHARP (CMN::ONSET 73/2) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::E4 NIL (CMN::ONSET 37) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::E4 NIL CMN::FERMATA (CMN::ONSET 38) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::D4 NIL (CMN::ONSET 39) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::G4 NIL (CMN::ONSET 40) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::F4 NIL (CMN::ONSET 41) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::F4 NIL (CMN::ONSET 42) (CMN::DURATION 3/2)))
                                   (CMN::CHORD (CMN::E4 NIL (CMN::ONSET 87/2) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::D4 CMN::SHARP CMN::FERMATA (CMN::ONSET 44) (CMN::DURATION 3)))
                                   CMN::DOUBLE-BAR)
                       (CMN::STAFF CMN::BAR
                                   CMN::TENOR-TREBLE
                                   CMN::D-MAJOR
                                   (CMN::METER CMN::COMMON-TIME)
                                   (CMN::CHORD (CMN::D4 NIL (CMN::TEXT "Herz-" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 3) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::E4 NIL (CMN::TEXT "lieb-" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 4) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::B3 NIL (CMN::TEXT "ster" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 5) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::C4 NIL (CMN::TEXT "Je-" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 6) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::B3 NIL (CMN::ONSET 13/2) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::A3 CMN::SHARP (CMN::TEXT "su," (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 7) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::B3 NIL (CMN::TEXT "was" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 8) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::A3 CMN::SHARP (CMN::TEXT "hast" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 9) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::B3 NIL (CMN::TEXT "du" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 10) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::C4 NIL (CMN::ONSET 21/2) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::D4 NIL (CMN::TEXT "ver-" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 11) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::C4 NIL (CMN::TEXT "bro" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 12) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::B3 NIL (CMN::ONSET 13) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::A3 CMN::SHARP CMN::FERMATA (CMN::TEXT "chen," (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 14) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::A3 CMN::SHARP (CMN::TEXT "dass" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 15) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::B3 NIL (CMN::TEXT "man" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 16) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::C4 NIL (CMN::TEXT "ein" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 17) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::D4 NIL (CMN::TEXT "solch" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 18) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::C4 NIL (CMN::ONSET 37/2) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::B3 NIL (CMN::TEXT "scharf" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 19) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::C4 NIL (CMN::ONSET 39/2) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::D4 NIL (CMN::TEXT "Ur-" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 20) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::E4 NIL (CMN::TEXT "teil" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 21) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::E4 NIL (CMN::TEXT "hat" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 22) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::D4 NIL (CMN::TEXT "ge-" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 23) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::D4 NIL (CMN::TEXT "spro-" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 24) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::C4 NIL (CMN::ONSET 25) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::A3 NIL CMN::FERMATA (CMN::TEXT "chen?" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 26) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::B3 NIL (CMN::TEXT "Was" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 27) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::A3 NIL (CMN::ONSET 55/2) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::G3 NIL (CMN::TEXT "ist" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 28) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::G3 NIL (CMN::TEXT "die" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 29) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::F3 NIL (CMN::ONSET 59/2) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::E3 NIL (CMN::TEXT "Schuld," (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 30) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::A3 NIL (CMN::ONSET 61/2) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::A3 NIL (CMN::TEXT "in" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 31) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::D4 NIL (CMN::TEXT "was" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 32) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::D4 NIL (CMN::TEXT "fuer" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 33) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::D4 NIL (CMN::TEXT "Mis-" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 34) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::C4 CMN::NATURAL (CMN::TEXT "se-" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 35) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::B3 NIL (CMN::TEXT "ta-" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 36) (CMN::DURATION 3/2)))
                                   (CMN::CHORD (CMN::A3 CMN::SHARP (CMN::ONSET 75/2) (CMN::DURATION 1/4)))
                                   (CMN::CHORD (CMN::B3 NIL (CMN::ONSET 151/4) (CMN::DURATION 1/4)))
                                   (CMN::CHORD (CMN::C4 NIL CMN::FERMATA (CMN::TEXT "ten" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 38) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::B3 NIL (CMN::TEXT "bist" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 39) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::B3 NIL (CMN::TEXT "du" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 40) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::A3 CMN::SHARP (CMN::ONSET 81/2) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::B3 NIL (CMN::TEXT "ge-" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 41) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::B3 NIL (CMN::TEXT "ra-" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 42) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::A3 CMN::SHARP (CMN::ONSET 43) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::F3 NIL CMN::FERMATA (CMN::TEXT "ten?" (CMN::Y #'Y-LYRICS) (CMN::FONT-SIZE 14)) (CMN::ONSET 44) (CMN::DURATION 3)))
                                   CMN::DOUBLE-BAR)
                       (CMN::STAFF CMN::BAR
                                   CMN::BASS
                                   CMN::D-MAJOR
                                   (CMN::METER CMN::COMMON-TIME)
                                   (CMN::CHORD (CMN::B3 NIL (CMN::ONSET 3) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::E3 NIL (CMN::ONSET 4) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::F3 NIL (CMN::ONSET 9/2) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::G3 NIL (CMN::ONSET 5) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::F3 NIL (CMN::ONSET 6) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::F3 NIL (CMN::ONSET 7) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::E3 NIL (CMN::ONSET 15/2) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::D3 NIL (CMN::ONSET 8) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::F3 NIL (CMN::ONSET 9) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::B2 NIL (CMN::ONSET 10) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::B3 NIL (CMN::ONSET 11) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::A3 CMN::SHARP (CMN::ONSET 12) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::B3 NIL (CMN::ONSET 13) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::F3 NIL CMN::FERMATA (CMN::ONSET 14) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::F3 NIL (CMN::ONSET 15) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::B3 NIL (CMN::ONSET 16) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::A3 NIL (CMN::ONSET 17) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::D3 NIL (CMN::ONSET 18) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::G3 NIL (CMN::ONSET 19) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::A3 NIL (CMN::ONSET 39/2) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::B3 NIL (CMN::ONSET 20) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::C4 NIL (CMN::ONSET 21) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::D4 NIL (CMN::ONSET 22) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::C4 NIL (CMN::ONSET 45/2) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::B3 NIL (CMN::ONSET 23) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::A3 NIL (CMN::ONSET 47/2) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::G3 NIL (CMN::ONSET 24) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::A3 NIL (CMN::ONSET 25) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::D3 NIL CMN::FERMATA (CMN::ONSET 26) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::B2 NIL (CMN::ONSET 27) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::E3 NIL (CMN::ONSET 28) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::F3 NIL (CMN::ONSET 57/2) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::G3 NIL (CMN::ONSET 29) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::C3 NIL (CMN::ONSET 30) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::D3 NIL (CMN::ONSET 31) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::D4 NIL (CMN::ONSET 32) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::C4 CMN::NATURAL (CMN::ONSET 65/2) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::B3 NIL (CMN::ONSET 33) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::A3 NIL (CMN::ONSET 67/2) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::G3 NIL (CMN::ONSET 34) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::F3 NIL (CMN::ONSET 69/2) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::E3 NIL (CMN::ONSET 35) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::D3 CMN::SHARP (CMN::ONSET 71/2) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::E3 NIL (CMN::ONSET 36) (CMN::DURATION 2)))
                                   (CMN::CHORD (CMN::A2 CMN::SHARP CMN::FERMATA (CMN::ONSET 38) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::B2 NIL (CMN::ONSET 39) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::C3 NIL (CMN::ONSET 40) (CMN::DURATION 1)))
                                   (CMN::CHORD (CMN::D3 NIL (CMN::ONSET 41) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::E3 NIL (CMN::ONSET 83/2) (CMN::DURATION 1/2)))
                                   (CMN::CHORD (CMN::F3 NIL (CMN::ONSET 42) (CMN::DURATION 2)))
                                   (CMN::CHORD (CMN::B2 NIL CMN::FERMATA (CMN::ONSET 44) (CMN::DURATION 3)))
                                   CMN::DOUBLE-BAR))))
  (write-string "error on cmnize" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

;;; test of the cmize function

(when (not (is-equal
            (cmize (realize *bwv244*) :tempo 120)
            `(CM::EVENTS (CM::NEW CM::SEQ
                                  :SUBOBJECTS
                                  (LIST (CM::NEW CM::SEQ
                                                 :SUBOBJECTS
                                                 (LIST (CM::NEW CM::MIDIMSG :TIME 0 :MSG (CM::MAKE-PROGRAM-CHANGE 0 0))
                                                       (CM::NEW CM::MIDIMSG :TIME 0 :MSG (CM::MAKE-PROGRAM-CHANGE 1 0))
                                                       (CM::NEW CM::MIDIMSG :TIME 0 :MSG (CM::MAKE-PROGRAM-CHANGE 2 0))
                                                       (CM::NEW CM::MIDIMSG :TIME 0 :MSG (CM::MAKE-PROGRAM-CHANGE 3 0))
                                                       (CM::NEW CM::MIDIMSG :TIME 0 :MSG (CM::MAKE-PROGRAM-CHANGE 4 0))
                                                       (CM::NEW CM::MIDIMSG :TIME 0 :MSG (CM::MAKE-PROGRAM-CHANGE 5 0))
                                                       (CM::NEW CM::MIDIMSG :TIME 0 :MSG (CM::MAKE-PROGRAM-CHANGE 6 0))
                                                       (CM::NEW CM::MIDIMSG :TIME 0 :MSG (CM::MAKE-PROGRAM-CHANGE 7 0))
                                                       (CM::NEW CM::MIDIMSG :TIME 0 :MSG (CM::MAKE-PROGRAM-CHANGE 8 0))
                                                       (CM::NEW CM::MIDIMSG :TIME 0 :MSG (CM::MAKE-PROGRAM-CHANGE 9 0))
                                                       (CM::NEW CM::MIDIMSG :TIME 0 :MSG (CM::MAKE-PROGRAM-CHANGE 10 0))
                                                       (CM::NEW CM::MIDIMSG :TIME 0 :MSG (CM::MAKE-PROGRAM-CHANGE 11 0))
                                                       (CM::NEW CM::MIDIMSG :TIME 0 :MSG (CM::MAKE-PROGRAM-CHANGE 12 0))
                                                       (CM::NEW CM::MIDIMSG :TIME 0 :MSG (CM::MAKE-PROGRAM-CHANGE 13 0))
                                                       (CM::NEW CM::MIDIMSG :TIME 0 :MSG (CM::MAKE-PROGRAM-CHANGE 14 0))
                                                       (CM::NEW CM::MIDIMSG :TIME 0 :MSG (CM::MAKE-PROGRAM-CHANGE 15 0))))
                                        (CM::NEW CM::SEQ
                                                 :SUBOBJECTS
                                                 (LIST (CM::NEW CM::SEQ
                                                                :SUBOBJECTS
                                                                (LIST (CM::NEW CM::MIDI :KEYNUM 59 :DURATION 1 :TIME 3 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 52 :DURATION 1/2 :TIME 4 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 54 :DURATION 1/2 :TIME 9/2 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 55 :DURATION 1 :TIME 5 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 54 :DURATION 1 :TIME 6 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 54 :DURATION 1/2 :TIME 7 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 52 :DURATION 1/2 :TIME 15/2 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 50 :DURATION 1 :TIME 8 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 54 :DURATION 1 :TIME 9 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 47 :DURATION 1 :TIME 10 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 59 :DURATION 1 :TIME 11 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 58 :DURATION 1 :TIME 12 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 59 :DURATION 1 :TIME 13 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 54 :DURATION 1 :TIME 14 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 54 :DURATION 1 :TIME 15 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 59 :DURATION 1 :TIME 16 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 57 :DURATION 1 :TIME 17 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 50 :DURATION 1 :TIME 18 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 55 :DURATION 1/2 :TIME 19 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 57 :DURATION 1/2 :TIME 39/2 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 59 :DURATION 1 :TIME 20 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 61 :DURATION 1 :TIME 21 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 62 :DURATION 1/2 :TIME 22 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 61 :DURATION 1/2 :TIME 45/2 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 59 :DURATION 1/2 :TIME 23 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 57 :DURATION 1/2 :TIME 47/2 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 55 :DURATION 1 :TIME 24 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 57 :DURATION 1 :TIME 25 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 50 :DURATION 1 :TIME 26 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 47 :DURATION 1 :TIME 27 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 52 :DURATION 1/2 :TIME 28 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 54 :DURATION 1/2 :TIME 57/2 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 55 :DURATION 1 :TIME 29 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 49 :DURATION 1 :TIME 30 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 50 :DURATION 1 :TIME 31 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 62 :DURATION 1/2 :TIME 32 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 60 :DURATION 1/2 :TIME 65/2 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 59 :DURATION 1/2 :TIME 33 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 57 :DURATION 1/2 :TIME 67/2 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 55 :DURATION 1/2 :TIME 34 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 54 :DURATION 1/2 :TIME 69/2 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 52 :DURATION 1/2 :TIME 35 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 51 :DURATION 1/2 :TIME 71/2 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 52 :DURATION 2 :TIME 36 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 46 :DURATION 1 :TIME 38 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 47 :DURATION 1 :TIME 39 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 49 :DURATION 1 :TIME 40 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 50 :DURATION 1/2 :TIME 41 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 52 :DURATION 1/2 :TIME 83/2 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 54 :DURATION 2 :TIME 42 :AMPLITUDE 100 :CHANNEL 6)
                                                                      (CM::NEW CM::MIDI :KEYNUM 47 :DURATION 3 :TIME 44 :AMPLITUDE 100 :CHANNEL 6)))
                                                       (CM::NEW CM::SEQ
                                                                :SUBOBJECTS
                                                                (LIST (CM::NEW CM::MIDI :KEYNUM 62 :DURATION 1 :TIME 3 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 64 :DURATION 1 :TIME 4 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 59 :DURATION 1 :TIME 5 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 61 :DURATION 1/2 :TIME 6 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 59 :DURATION 1/2 :TIME 13/2 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 58 :DURATION 1 :TIME 7 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 59 :DURATION 1 :TIME 8 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 58 :DURATION 1 :TIME 9 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 59 :DURATION 1/2 :TIME 10 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 61 :DURATION 1/2 :TIME 21/2 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 62 :DURATION 1 :TIME 11 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 61 :DURATION 1 :TIME 12 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 59 :DURATION 1 :TIME 13 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 58 :DURATION 1 :TIME 14 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 58 :DURATION 1 :TIME 15 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 59 :DURATION 1 :TIME 16 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 61 :DURATION 1 :TIME 17 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 62 :DURATION 1/2 :TIME 18 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 61 :DURATION 1/2 :TIME 37/2 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 59 :DURATION 1/2 :TIME 19 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 61 :DURATION 1/2 :TIME 39/2 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 62 :DURATION 1 :TIME 20 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 64 :DURATION 1 :TIME 21 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 64 :DURATION 1 :TIME 22 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 62 :DURATION 1 :TIME 23 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 62 :DURATION 1 :TIME 24 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 61 :DURATION 1 :TIME 25 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 57 :DURATION 1 :TIME 26 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 59 :DURATION 1/2 :TIME 27 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 57 :DURATION 1/2 :TIME 55/2 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 55 :DURATION 1 :TIME 28 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 55 :DURATION 1/2 :TIME 29 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 54 :DURATION 1/2 :TIME 59/2 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 52 :DURATION 1/2 :TIME 30 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 57 :DURATION 1/2 :TIME 61/2 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 57 :DURATION 1 :TIME 31 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 62 :DURATION 1 :TIME 32 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 62 :DURATION 1 :TIME 33 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 62 :DURATION 1 :TIME 34 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 60 :DURATION 1 :TIME 35 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 59 :DURATION 3/2 :TIME 36 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 58 :DURATION 1/4 :TIME 75/2 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 59 :DURATION 1/4 :TIME 151/4 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 61 :DURATION 1 :TIME 38 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 59 :DURATION 1 :TIME 39 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 59 :DURATION 1/2 :TIME 40 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 58 :DURATION 1/2 :TIME 81/2 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 59 :DURATION 1 :TIME 41 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 59 :DURATION 1 :TIME 42 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 58 :DURATION 1 :TIME 43 :AMPLITUDE 100 :CHANNEL 4)
                                                                      (CM::NEW CM::MIDI :KEYNUM 54 :DURATION 3 :TIME 44 :AMPLITUDE 100 :CHANNEL 4)))
                                                       (CM::NEW CM::SEQ
                                                                :SUBOBJECTS
                                                                (LIST (CM::NEW CM::MIDI :KEYNUM 66 :DURATION 1 :TIME 3 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 67 :DURATION 1 :TIME 4 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 62 :DURATION 1/2 :TIME 5 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 64 :DURATION 1/2 :TIME 11/2 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 66 :DURATION 1 :TIME 6 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 61 :DURATION 1 :TIME 7 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 66 :DURATION 1 :TIME 8 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 66 :DURATION 1 :TIME 9 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 66 :DURATION 1 :TIME 10 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 66 :DURATION 1 :TIME 11 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 66 :DURATION 2 :TIME 12 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 66 :DURATION 1 :TIME 14 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 66 :DURATION 1 :TIME 15 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 66 :DURATION 1 :TIME 16 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 69 :DURATION 1 :TIME 17 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 69 :DURATION 1 :TIME 18 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 71 :DURATION 1/2 :TIME 19 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 69 :DURATION 1/2 :TIME 39/2 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 67 :DURATION 1 :TIME 20 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 69 :DURATION 1 :TIME 21 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 69 :DURATION 1 :TIME 22 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 74 :DURATION 1/2 :TIME 23 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 73 :DURATION 1/2 :TIME 47/2 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 71 :DURATION 1 :TIME 24 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 69 :DURATION 1/2 :TIME 25 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 67 :DURATION 1/2 :TIME 51/2 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 66 :DURATION 1 :TIME 26 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 66 :DURATION 1 :TIME 27 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 64 :DURATION 1 :TIME 28 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 62 :DURATION 1 :TIME 29 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 64 :DURATION 1 :TIME 30 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 62 :DURATION 1/2 :TIME 31 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 64 :DURATION 1/2 :TIME 63/2 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 66 :DURATION 1 :TIME 32 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 66 :DURATION 1 :TIME 33 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 67 :DURATION 1 :TIME 34 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 66 :DURATION 1 :TIME 35 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 66 :DURATION 1/2 :TIME 36 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 63 :DURATION 1/2 :TIME 73/2 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 64 :DURATION 1 :TIME 37 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 64 :DURATION 1 :TIME 38 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 62 :DURATION 1 :TIME 39 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 67 :DURATION 1 :TIME 40 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 66 :DURATION 1 :TIME 41 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 66 :DURATION 3/2 :TIME 42 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 64 :DURATION 1/2 :TIME 87/2 :AMPLITUDE 100 :CHANNEL 3)
                                                                      (CM::NEW CM::MIDI :KEYNUM 63 :DURATION 3 :TIME 44 :AMPLITUDE 100 :CHANNEL 3)))
                                                       (CM::NEW CM::SEQ
                                                                :SUBOBJECTS
                                                                (LIST (CM::NEW CM::MIDI :KEYNUM 71 :DURATION 1 :TIME 3 :AMPLITUDE 100 :CHANNEL 1)
                                                                      (CM::NEW CM::MIDI :KEYNUM 71 :DURATION 1 :TIME 4 :AMPLITUDE 100 :CHANNEL 1)
                                                                      (CM::NEW CM::MIDI :KEYNUM 71 :DURATION 1 :TIME 5 :AMPLITUDE 100 :CHANNEL 1)
                                                                      (CM::NEW CM::MIDI :KEYNUM 70 :DURATION 1/2 :TIME 6 :AMPLITUDE 100 :CHANNEL 1)
                                                                      (CM::NEW CM::MIDI :KEYNUM 68 :DURATION 1/2 :TIME 13/2 :AMPLITUDE 100 :CHANNEL 1)
                                                                      (CM::NEW CM::MIDI :KEYNUM 66 :DURATION 1 :TIME 7 :AMPLITUDE 100 :CHANNEL 1)
                                                                      (CM::NEW CM::MIDI :KEYNUM 71 :DURATION 1 :TIME 8 :AMPLITUDE 100 :CHANNEL 1)
                                                                      (CM::NEW CM::MIDI :KEYNUM 73 :DURATION 1 :TIME 9 :AMPLITUDE 100 :CHANNEL 1)
                                                                      (CM::NEW CM::MIDI :KEYNUM 74 :DURATION 1 :TIME 10 :AMPLITUDE 100 :CHANNEL 1)
                                                                      (CM::NEW CM::MIDI :KEYNUM 74 :DURATION 1 :TIME 11 :AMPLITUDE 100 :CHANNEL 1)
                                                                      (CM::NEW CM::MIDI :KEYNUM 76 :DURATION 1 :TIME 12 :AMPLITUDE 100 :CHANNEL 1)
                                                                      (CM::NEW CM::MIDI :KEYNUM 74 :DURATION 1 :TIME 13 :AMPLITUDE 100 :CHANNEL 1)
                                                                      (CM::NEW CM::MIDI :KEYNUM 73 :DURATION 1 :TIME 14 :AMPLITUDE 100 :CHANNEL 1)
                                                                      (CM::NEW CM::MIDI :KEYNUM 73 :DURATION 1 :TIME 15 :AMPLITUDE 100 :CHANNEL 1)
                                                                      (CM::NEW CM::MIDI :KEYNUM 74 :DURATION 1 :TIME 16 :AMPLITUDE 100 :CHANNEL 1)
                                                                      (CM::NEW CM::MIDI :KEYNUM 76 :DURATION 1 :TIME 17 :AMPLITUDE 100 :CHANNEL 1)
                                                                      (CM::NEW CM::MIDI :KEYNUM 78 :DURATION 1/2 :TIME 18 :AMPLITUDE 100 :CHANNEL 1)
                                                                      (CM::NEW CM::MIDI :KEYNUM 76 :DURATION 1/2 :TIME 37/2 :AMPLITUDE 100 :CHANNEL 1)
                                                                      (CM::NEW CM::MIDI :KEYNUM 74 :DURATION 1 :TIME 19 :AMPLITUDE 100 :CHANNEL 1)
                                                                      (CM::NEW CM::MIDI :KEYNUM 79 :DURATION 1 :TIME 20 :AMPLITUDE 100 :CHANNEL 1)
                                                                      (CM::NEW CM::MIDI :KEYNUM 79 :DURATION 1 :TIME 21 :AMPLITUDE 100 :CHANNEL 1)
                                                                      (CM::NEW CM::MIDI :KEYNUM 78 :DURATION 1/2 :TIME 22 :AMPLITUDE 100 :CHANNEL 1)
                                                                      (CM::NEW CM::MIDI :KEYNUM 76 :DURATION 1/2 :TIME 45/2 :AMPLITUDE 100 :CHANNEL 1)
                                                                      (CM::NEW CM::MIDI :KEYNUM 78 :DURATION 1 :TIME 23 :AMPLITUDE 100 :CHANNEL 1)
                                                                      (CM::NEW CM::MIDI :KEYNUM 76 :DURATION 2 :TIME 24 :AMPLITUDE 100 :CHANNEL 1)
                                                                      (CM::NEW CM::MIDI :KEYNUM 74 :DURATION 1 :TIME 26 :AMPLITUDE 100 :CHANNEL 1)
                                                                      (CM::NEW CM::MIDI :KEYNUM 74 :DURATION 1 :TIME 27 :AMPLITUDE 100 :CHANNEL 1)
                                                                      (CM::NEW CM::MIDI :KEYNUM 73 :DURATION 1 :TIME 28 :AMPLITUDE 100 :CHANNEL 1)
                                                                      (CM::NEW CM::MIDI :KEYNUM 71 :DURATION 1 :TIME 29 :AMPLITUDE 100 :CHANNEL 1)
                                                                      (CM::NEW CM::MIDI :KEYNUM 69 :DURATION 1 :TIME 30 :AMPLITUDE 100 :CHANNEL 1)
                                                                      (CM::NEW CM::MIDI :KEYNUM 66 :DURATION 1/2 :TIME 31 :AMPLITUDE 100 :CHANNEL 1)
                                                                      (CM::NEW CM::MIDI :KEYNUM 67 :DURATION 1/2 :TIME 63/2 :AMPLITUDE 100 :CHANNEL 1)
                                                                      (CM::NEW CM::MIDI :KEYNUM 69 :DURATION 1 :TIME 32 :AMPLITUDE 100 :CHANNEL 1)
                                                                      (CM::NEW CM::MIDI :KEYNUM 69 :DURATION 1 :TIME 33 :AMPLITUDE 100 :CHANNEL 1)
                                                                      (CM::NEW CM::MIDI :KEYNUM 71 :DURATION 1 :TIME 34 :AMPLITUDE 100 :CHANNEL 1)
                                                                      (CM::NEW CM::MIDI :KEYNUM 69 :DURATION 1 :TIME 35 :AMPLITUDE 100 :CHANNEL 1)
                                                                      (CM::NEW CM::MIDI :KEYNUM 67 :DURATION 2 :TIME 36 :AMPLITUDE 100 :CHANNEL 1)
                                                                      (CM::NEW CM::MIDI :KEYNUM 66 :DURATION 1 :TIME 38 :AMPLITUDE 100 :CHANNEL 1)
                                                                      (CM::NEW CM::MIDI :KEYNUM 78 :DURATION 1 :TIME 39 :AMPLITUDE 100 :CHANNEL 1)
                                                                      (CM::NEW CM::MIDI :KEYNUM 76 :DURATION 1 :TIME 40 :AMPLITUDE 100 :CHANNEL 1)
                                                                      (CM::NEW CM::MIDI :KEYNUM 74 :DURATION 1 :TIME 41 :AMPLITUDE 100 :CHANNEL 1)
                                                                      (CM::NEW CM::MIDI :KEYNUM 73 :DURATION 2 :TIME 42 :AMPLITUDE 100 :CHANNEL 1)
                                                                      (CM::NEW CM::MIDI :KEYNUM 71 :DURATION 3 :TIME 44 :AMPLITUDE 100 :CHANNEL 1)))))))
                          ,(namestring *default-midi-file*)
                         :TEMPO
                         120) ))
  (write-string "error on cmize" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

;;; End of test

(if *test-result*
  (progn
    (write-string "test ok :compo-cm" *standard-output*)
    (write-string (make-string 1 :initial-element #\newline) *standard-output*) )
  (progn
    (write-string "test not ok :compo-cm" *standard-output*)
    (write-string (make-string 1 :initial-element #\newline) *standard-output*) ) )