;;; A Common Lisp implementation of the compo protocol Version 2
;;;
;;; Package :compo
;;;
;;; Copyright (C) 2001  Bruno LARTILLOT
;;; 
;;; This program is free software; you can redistribute it and/or
;;; modify it under the terms of the GNU General Public License
;;; as published by the Free Software Foundation; either version 2
;;; of the License, or any later version.
;;;
;;; This program is distributed in the hope that it will be useful,
;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
;;; along with this program; if not, write to the Free Software
;;; Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

(in-package :compo)

(defclass context-item (compo) ()
  (:documentation

"Class : 
   context-item
Direct Superclasses :
   compo
Purpose :
   Like compositions, contexts are organized in a hierarchy and can be given a sublist of
   contexts. For that reason, the context-item class derives from the compo class.
   The realization process (see the 'realize' generic function) relies on a matching of
   a composition's tree structure to a context's one, (compare that to applying
   arguments to a function's parameters in an applicative language).
   'context-item' is the base class of any context item and in extension of any context
   (see 'standard-context').
   If an atomic context-item is given rather than a list as a value to the 'subs' slot,
   it is equivalent to an infinite list of the given context item.
   Note that though we are speaking about context-items, we are using the term 'context'.
   It is because 'context-item' is just the abstract superclass of contexts, so it makes
   no sense to consider context-items as objects existing by themselves." ) )

(defmethod initialize-instance ((self context-item) 
                                &key name (subs self) &allow-other-keys )

"Primary method
   initialize-instance specialized on context-item.
Purpose
   As a default, a context-item is created with itself as a value to its 'subs' slot."

  (declare (ignore name))
  (call-next-method)
  (setf (subs self) subs)

  ; CLisp expects 'initialize-instance' to return 'self'
  self )