;;; A Common Lisp implementation of the compo protocol Version 2
;;;
;;; Package :compo
;;;
;;; Copyright (C) 2001  Bruno LARTILLOT
;;; 
;;; This program is free software; you can redistribute it and/or
;;; modify it under the terms of the GNU General Public License
;;; as published by the Free Software Foundation; either version 2
;;; of the License, or any later version.
;;;
;;; This program is distributed in the hope that it will be useful,
;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
;;; along with this program; if not, write to the Free Software
;;; Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

(in-package :compo)

(defclass coercion (context-item) ()
  (:documentation 

"Class :
   coercion
Direct Superclasses :
   context-item
Purpose :
   Base context item provided for the applying of coercions on a composition." ) )

(defmethod realize-using-context-item ((coercion coercion) (compo compo)
                                       &rest restargs &key &allow-other-keys)

"Primary method
   realize-using-context-item specialized on 'coercion'
Behaviour
   The next method is first called.
   The coercer list to be used below is :
   . The value of the 'coercer' slot in the composition, if it is a list;
   . A circular list of the value of the 'coercer' slot in the composition, if it is an
   atom.
   The 'coerce-compo' generic function is applied to each subcomposition of the
   composition and a clone of the corresponding coercer in the coercer list obtained
   above.
   Each call to 'coerce-compo' is given the current composition as a :super-compo key
   argument and the previous subcomposition from the subcomposition list (nil if it is 
   the first) as a :prev-compo key argument.
   The slot 'subs' in the composition is set to the list obtained when appending all the
   results of the previous calls to 'coerce-compo'."

  (call-next-method)
  (setf (subs compo)
        (let ((prev nil))
          (mapcan #'(lambda (a b)
                      (prog1
                        (apply #'coerce-compo a (clone b) 
                               :super-compo compo
                               :prev-compo prev
                               restargs )
                        (setf prev a) ) )
                  (subs compo)
                  (let ((x (coercer compo)))
                    (if (consp x)
                      x
                      (circdr x) ) ) ) ) )
  compo )