;;; A Common Lisp implementation of the compo protocol Version 2
;;;
;;; Package :compo
;;;
;;; Copyright (C) 2001  Bruno LARTILLOT
;;; 
;;; This program is free software; you can redistribute it and/or
;;; modify it under the terms of the GNU General Public License
;;; as published by the Free Software Foundation; either version 2
;;; of the License, or any later version.
;;;
;;; This program is distributed in the hope that it will be useful,
;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
;;; along with this program; if not, write to the Free Software
;;; Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

(in-package :compo)

(defclass evaluation (context-item)()
  (:documentation 

"Class :
   evaluation
Direct Superclasses :
   context-item
Purpose :
   Realizing a composition with an instance of the context-item 'evaluation' is intended
  to cause its numeric properties to have :
   . Their value set to the result of their lisp evaluation if they are not quoted;
   . Their arguments set to to the result of their lisp evaluation if they are quoted.
   Ex. : (+ 3 4) => 7
         (* (+ 3 2) 2)  => 10
         '(rational (+ 1/2 1) (* 2 2)) => '(rational 3/2 4)
         '(rational (list 1) 9/8) => '(rational (1) 9/8)
         '((member (* 2 3)) (+ 3 4)) => '(member 6 7)
   (for a better comprehension of the last example, see the context item
   'transformation').
   Note that this default behaviour for numeric properties is provided though the class
   'compo' doesn't define any. For a concrete example, see a subclass of 'abstract-compo'
   like the class 'note' in the :note package.
   A lexical access is given to the value (i.e. to what will be the value at the time of
   the realization) of each numeric property in the supercomposition of the currently
   realized subcomposition. The lexical name is the property name preceded by 'super-'
   (for instance 'super-voi' for the property 'voi' in the class 'note').
   A lexical access is given to the value (i.e. to what will be the value at the time of
   the realization) of each numeric property in the previous subcomposition from the
   currently realized subcomposition. The lexical name is the property name preceded by
   'prev-' (for instance 'prev-voi' for the property 'voi' in the class 'note').
   For instance, if a subcomposition has a voice property set to (+ super-voi 2), and at
   the time the realization of the subcomposition with the evaluation context occurs,
   the voice of its supercomposition is set to the value 3, the new value for the voice
   property of the subcomposition will be 5." ) )

(defmethod realize-using-context-item ((context-item evaluation) 
                                       (compo compo)
                                       &key super-compo prev-compo
                                       &allow-other-keys)

"Primary method
   realize-using-context-item specialized on the evaluation type.
Arguments
   An instance of the context item 'evaluation' as a specializer.
   The composition being realized.
   The supercomposition of the composition being realized, or nil if the composition being
   realized is the tree root.
   The previous composition from the composition being realized in a given subcomposition
   list, or nil if the the composition being realized is the first in the list.
Behaviour
   The next method is first called.
   The evaluation is delegated to the generic function 'evaluate' (see 'evaluate')."

  (call-next-method)
  (evaluate compo super-compo prev-compo)
  compo )