;;; A Common Lisp implementation of the compo protocol Version 2
;;;
;;; Package :compo
;;;
;;; Copyright (C) 2001  Bruno LARTILLOT
;;; 
;;; This program is free software; you can redistribute it and/or
;;; modify it under the terms of the GNU General Public License
;;; as published by the Free Software Foundation; either version 2
;;; of the License, or any later version.
;;;
;;; This program is distributed in the hope that it will be useful,
;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
;;; along with this program; if not, write to the Free Software
;;; Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

(in-package :compo)

(defclass realization (context-item)
  ((context
    :initarg :context
    :initform nil
    :type context-item ))
  (:documentation

"Class
   realization
Direct Superclasses
   context-item
Slots
   context : of type context-item
     initarg : :context
     defaults to nil
Purpose
   This context item reflexively defines the realization process itself as a context
   item." ) )

(defmethod is-equal ((x realization) (y realization))

"Primary method
   is-equal specialized on the realization type.
Purpose
   Return x if the next-method returns a non-nil value, and 'is-equal' applied to the
   respective values of the slot 'context' in x and y is true."

  (with-slots ((x-context context)) x
    (with-slots ((y-context context)) y
      (and
       (call-next-method)
       (is-equal x-context y-context)
       x ) ) ) )

(defmethod clone-slots ((copied realization) (copy realization))

"Primary method
   clone-slots specialized on the realization type
Purpose
   First calls the next primary method.
   Then sets the value of the slot 'context' in the copy to a clone of the current value
   of the slot 'context' in the cloned object."

  (call-next-method)
  (with-slots ((copied-context context)) copied
    (with-slots ((copy-context context)) copy
      (setf copy-context (clone copied-context)) ) ) )

(defmethod realize-using-context-item ((context-item realization) 
                                       (compo abstract-compo) &rest restargs)

"Primary method
   realize-using-context-item specialized on the 'realization' and the 'abstract-compo'
   types.
Purpose
   The next method is first called.
   'realize-using-context-item' is applied to the current value of the 'context' slot in
   the current context (the instance of the class which is a subclass of 'realization'
   received as a specializer argument), the composition and the received remaining
   argument list."

  (call-next-method)
  (with-slots (context) context-item
    (apply #'realize-using-context-item
           context
           compo
           restargs ) )
  compo )