;;; A Common Lisp implementation of the compo protocol Version 2
;;;
;;; Package :compo
;;;
;;; Copyright (C) 2001  Bruno LARTILLOT
;;; 
;;; This program is free software; you can redistribute it and/or
;;; modify it under the terms of the GNU General Public License
;;; as published by the Free Software Foundation; either version 2
;;; of the License, or any later version.
;;;
;;; This program is distributed in the hope that it will be useful,
;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
;;; along with this program; if not, write to the Free Software
;;; Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

(in-package :compo)

(defclass sorting (context-item)()
  (:documentation 

"Class
   sorting
Direct Superclasses
   context-item
Purpose
   This context item is responsible, for a given composition being realized, of 
   the sorting of its subcompositions." ) )

(defmethod realize-using-context-item ((context-item sorting) 
                                       (compo compo) &key &allow-other-keys)

"Primary method
   realize-using-context-item specialized on the sorting type
Behaviour
   The next method is first called.
   Sort the subcompositions of the composition being realized, giving it the result as a
   new subcomposition list, using 'compo-lessp' as a comparison predicate."

  (declare (ignore context-item))
  (call-next-method)
  (with-slots (subs) compo
    (setf subs
          (sort subs
                #'(lambda (x y) 
                    (compo-lessp x y) ) ) ) )
  compo )