;;; A Common Lisp implementation of the compo protocol Version 2
;;;
;;; Package :compo
;;;
;;; Copyright (C) 2001  Bruno LARTILLOT
;;; 
;;; This program is free software; you can redistribute it and/or
;;; modify it under the terms of the GNU General Public License
;;; as published by the Free Software Foundation; either version 2
;;; of the License, or any later version.
;;;
;;; This program is distributed in the hope that it will be useful,
;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
;;; along with this program; if not, write to the Free Software
;;; Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

(in-package :compo)

(defgeneric realize-using-context-item (context-item compo &key &allow-other-keys) 
  (:documentation

"Generic function
   realize-using-context-item (context-item compo &key &allow-other-keys)
Arguments
   A context item as a specializer.
   A composition (or a working copy of the composition) to be realized.
Values
   Normally returns compo modified in some way, depending of each involved primary
   method.
Purpose
   Since the composition is normally a copy from the original (see 'realize', and except
   if the caller explicitly choses to pass the original by using the destructive function 
   nrealize rather than realize), it can be freely modified by each method. Thus, the
   copy of compo derives incrementally towards the solution. So in the description of
   each primary method for this function, wherever the expression 'the composition'
   occurs, it naturally refers to the copy of the original which is granted to remain
   unchanged after calling the non-destructive function 'realize'." ) )

(defmethod realize-using-context-item ((context-item context-item) 
                                       (compo abstract-compo) 
                                       &key &allow-other-keys)

"Primary method
   realize-using-context-item specialized on 'context-item' and 'abstract-compo'.
Behaviour
   As a default, the composition is returned unchanged."

  (declare (ignore context-item))
  compo )