;;; A Common Lisp implementation of the compo protocol Version 2
;;;
;;; Package :compo
;;;
;;; Copyright (C) 2001  Bruno LARTILLOT
;;; 
;;; This program is free software; you can redistribute it and/or
;;; modify it under the terms of the GNU General Public License
;;; as published by the Free Software Foundation; either version 2
;;; of the License, or any later version.
;;;
;;; This program is distributed in the hope that it will be useful,
;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
;;; along with this program; if not, write to the Free Software
;;; Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

(in-package :compo)

(defgeneric clone-slots (copied copy)
  (:documentation

"Generic Function
   clone-slots (copied copy)
Arguments
   The value to be cloned
   The copy being constructed
Behaviour
   This generic function implements the slot copy part of the cloning process, applied
   to CLOS objects. It is intended to be called only by the generic function 'clone'
   and to be specialized to any user class managing instance slots." ) )

(defmethod clone-slots (copied copy)

"Primary method
   clone-slots specialized on 't'
Purpose
   Nothing is done. This is just a default method to be invoked by the 'clone' generic
   function on an instance of any user class which would not have defined a specialized
   clone-slots method. 
   For any subclass of a standard object which defines instance slots, 'clone-slots'
   should be specialized in order to clone and set the slots defined by this subclass."

  (declare (ignore copied copy))
  nil )

(defmethod clone-slots ((copied abstract-compo) (copy abstract-compo))

"Primary method
   clone-slots specialized on 'abstract-compo'
Purpose
   The next clone-slots method is called.
   The slot 'name' in the copy is set to a clone of the slot 'name' in the model.
   The slot 'coercer' in the copy is set to a clone of the slot 'coercer' in the model.
   The slot 'subs' in the copy is set to either the copy itself in the case where the
   slot 'subs' in the cloned object is 'eq' to the cloned object itself, or to a clone of
   the slot 'subs' in the cloned object."

  (call-next-method)
  (setf (name copy) (name copied))
  (setf (coercer copy) (coercer copied))
  (if (eq (subs copied) copied)
    (setf (subs copy) copy)
    (setf (subs copy) (clone (subs copied))) ) )