;;; A Common Lisp implementation of the compo protocol Version 2
;;;
;;; Package :compo
;;;
;;; Copyright (C) 2001  Bruno LARTILLOT
;;; 
;;; This program is free software; you can redistribute it and/or
;;; modify it under the terms of the GNU General Public License
;;; as published by the Free Software Foundation; either version 2
;;; of the License, or any later version.
;;;
;;; This program is distributed in the hope that it will be useful,
;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
;;; along with this program; if not, write to the Free Software
;;; Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

(in-package :compo)

(defgeneric evaluate (compo super-compo prev-compo)
  (:documentation

"Generic Function
   evaluate (compo super-compo prev-compo)
Arguments
  The composition being realized.
  Its supercomposition, or nil if composition being realized is the tree root.
  The previous composition from the composition being realized in a given subcomposition
  list, or nil if the composition being realized is the first in the list.
Values
   compo <<evaluated>>.
Purpose
   This generic function is normally called by the realization mechanism specialized on
   the context item 'evaluation'. Subclasses of 'compo' that defines numeric properties
   should specialized 'evaluate' in order to specify how those numeric properties are to
   be evaluate in the realization process.
   For a description of the evaluation behaviour, see the 'evaluation' context-item." ) )

(defmethod evaluate ((compo compo) super-compo prev-compo)

"Primary method
   evaluate specialized on 'compo'
Purpose
   As a default, the composition is returned unchanged."

  (declare (ignore super-compo prev-compo)) )