;;; A Common Lisp implementation of the compo protocol Version 2
;;;
;;; Package :compo
;;;
;;; Copyright (C) 2001  Bruno LARTILLOT
;;; 
;;; This program is free software; you can redistribute it and/or
;;; modify it under the terms of the GNU General Public License
;;; as published by the Free Software Foundation; either version 2
;;; of the License, or any later version.
;;;
;;; This program is distributed in the hope that it will be useful,
;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
;;; along with this program; if not, write to the Free Software
;;; Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

(in-package :compo)

(defmacro sugar-compo (macro-name class-name &key name subs)

"Macro
   sugar-compo (macro-name class-name &key :name :subs)
Arguments
   The name of the macro to be produced.
   The name of a subclass of 'compo'.
   A default name as a :name key argument.
   A default subs as a :subs key argument.
Values
   Returns a new macro named by the given name and able to construct new compositions of
   the given class, with the given name and subs as default key-arguments.
Purpose
   This macro can be considered as the <<reader>> of compo (think of the term <<reader>>
   in the same meaning as in Lisp). It allows the construction of hierarchies of
   compositions in a more natural syntax than using make-instance. For example, one can
   write :
     (compo \"test\" ()()())
   rather than :
     (make-instance 'compo
       :name \"test\"
       :subs (list (make-instance 'compo)
                   (make-instance 'compo)
                   (make-instance 'compo) ) )
   When compo is loaded, sugar-compo is applied to each subclass of 'compo' defined in
   the scope of the package :compo, i.e. the classes 'compo' 'ccompo' and 'context-item'
   and each context item defined in that package plus the standard context, using their
   name as a macro name. So at the begining of a compo session, one can safely enter :
     (compo ()()())
     (atomization)
     (standard-context)
     ..."

  `(progn
     (setf (get ',class-name 'compo-subclass) t)
     (defmacro ,macro-name (&rest restargs)
       (append (list 'make-instance '',class-name)
               (read-compo
                (normalize-compo restargs
                                 ',class-name (make-instance ',class-name) nil ) )
               (and ,name (list :name (clone ,name)))
               (and ,subs (list :subs (clone ,subs))) ) ) ) )

(sugar-compo compo compo)
(sugar-compo ccompo ccompo)
(sugar-compo compo-coercive compo-coercive)
(sugar-compo context-item context-item)
(sugar-compo atomization atomization)
(sugar-compo coercion coercion)
(sugar-compo evaluation evaluation)
(sugar-compo granulation granulation)
(sugar-compo integration integration)
(sugar-compo realization realization)
(sugar-compo recursion recursion)
(sugar-compo selection selection)
(sugar-compo sorting sorting)
(sugar-compo transformation transformation)
(sugar-compo unicity unicity)
(sugar-compo standard-context standard-context)