;;; A Common Lisp implementation of the compo protocol Version 2
;;;
;;; Package :compo
;;;
;;; Copyright (C) 2001  Bruno LARTILLOT
;;; 
;;; This program is free software; you can redistribute it and/or
;;; modify it under the terms of the GNU General Public License
;;; as published by the Free Software Foundation; either version 2
;;; of the License, or any later version.
;;;
;;; This program is distributed in the hope that it will be useful,
;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
;;; along with this program; if not, write to the Free Software
;;; Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

(in-package :compo)

(defun normalize-compo (l class ex defaults &rest restargs)

"Function
   normalize-compo (l class ex &rest restargs)
Arguments
   The part of a lambda-list to be normalized.
   The class object of the root of the composition currently being constructed.
   An exemplary of this class.
   A remaining key argument list.
Values
   The lambda list part normalized.
Purpose
   This function is used by the macro 'sugar-compo' to convert the parameters readed in
   the input stream to key arguments that can be passed to 'make-instance'.
   'normalize-compo' manages the recursive normalization of subcompositions, but
   delegates the normalization of any other parameter to the generic function
   'specialized-normalize', to allow subclasses of 'compo' to redefines only this part
   of the process."

  (labels ((f (x)
             (if (and x (atom x))
               x
               (cons
                'make-instance
                (if (and (symbolp (car x))
                         (get (car x) 'compo-subclass) )
                  (append `(',(car x))
                          (apply #'normalize-compo (cdr x) class ex defaults restargs)
                          defaults )
                  (append `(',class)
                          (apply #'normalize-compo x class ex defaults restargs)
                          defaults ) ) ) ) ))

    (and l
      (or
       (apply #'specialized-normalize ex class l defaults restargs)
       (cond
        ((eq (car l) :subs)
         (append
          defaults
          (list* :subs
                 (f (cadr l))
                 (apply #'normalize-compo (cddr l) class ex defaults restargs) ) ) )
        (t
         (append
          defaults
          (list :subs
                (append
                 '(list)
                 (mapcar #'(lambda (x)
                             (f x) )
                         l ) ) ) ) ) ) ) ) ) )