;;; A Common Lisp implementation of the compo protocol Version 2
;;;
;;; Package :compo
;;;
;;; Copyright (C) 2001  Bruno LARTILLOT
;;; 
;;; This program is free software; you can redistribute it and/or
;;; modify it under the terms of the GNU General Public License
;;; as published by the Free Software Foundation; either version 2
;;; of the License, or any later version.
;;;
;;; This program is distributed in the hope that it will be useful,
;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
;;; along with this program; if not, write to the Free Software
;;; Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

(in-package :compo)

(proclaim '(special *test-result*))

(setf *test-result* t)

;;; test of the circar constructor

(when (not (let ((a (circar 1))) (and (eq (car a) a)) (= (cdr a) 1)))
  (write-string "error on circar" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

;;; test of the circdr constructor

(when (not (let ((a (circdr 1))) (and (eq (cdr a) a)) (= (car a) 1)))
  (write-string "error on circdr" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

;;; test of the mydeftype macro

(mydeftype test-type () 'rational)
(when (not (get 'test-type 'type-spec-p))
  (write-string "error on mydeftype" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (get 'array 'type-spec-p))
  (write-string "error on mydeftype" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

;;; test of the coerce-value function along with the closestc coercer specifier

(when (not (eql (coerce-value 1 'rational) 1))
  (write-string "error on coerce-value (1)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eql (coerce-value 1 '(rational 0 3)) 1))
  (write-string "error on coerce-value (2)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eql (coerce-value 1 '(identity)) 1))
  (write-string "error on coerce-value (3)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eql (coerce-value 1 '(closestc 0 3)) 0))
  (write-string "error on coerce-value (4)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eql (coerce-value 1 '(closestc 2 3)) 2))
  (write-string "error on coerce-value (5)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eql (coerce-value -1 '(closestc -3 3)) -3))
  (write-string "error on coerce-value (6)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

;;; test of the compo constructor along with 'is-equal' and 'clone'

(when (not (is-equal (compo "compo1" ())
                     (compo "compo1" ()) ))
  (write-string "error on (is-equal compo compo)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(let ((test (compo ())))
  (when (not (is-equal test (clone test)))
    (write-string "error on (is-equal compo (clone compo))" *standard-output*)
    (write-string (make-string 1 :initial-element #\newline) *standard-output*)
    (setf *test-result* nil) ) )

(when (is-equal (compo)
                (compo ()) )
  (write-string "error on (not (is-equal compo (compo ())))" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(let ((test (compo)))
  (setf (subs (clone test)) (compo))
  (when (not (is-equal test (compo)))
    (write-string "error on (clone (compo))" *standard-output*)
    (write-string (make-string 1 :initial-element #\newline) *standard-output*)
    (setf *test-result* nil) ) )

;;; test of the context-item constructor along with is-equal and clone

(when (not (is-equal (context-item "name" :coercer t (integration))
                     (context-item "name" :coercer t (integration)) ))
  (write-string "error on (is-equal context-item context-item)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(let ((test (context-item (recursion))))
  (when (not (is-equal test (clone test)))
    (write-string "error on (is-equal context-item (clone context-item))" *standard-output*)
    (write-string (make-string 1 :initial-element #\newline) *standard-output*)
    (setf *test-result* nil) ) )

(when (is-equal (context-item)
                (context-item (context-item)) )
  (write-string "error on (not (is-equal context-item (context-item (context-item))))" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(let* ((test (context-item))
       (test2 (clone test)) )
  (setf (subs test2) (list (realization)))
  (setf (coercer test2) t)
  (when (not (is-equal test (context-item)))
    (write-string "error on (clone context-item)" *standard-output*)
    (write-string (make-string 1 :initial-element #\newline) *standard-output*)
    (setf *test-result* nil) ) )

;;; End of test

(if *test-result*
  (progn
    (write-string "test ok :compo" *standard-output*)
    (write-string (make-string 1 :initial-element #\newline) *standard-output*) )
  (progn
    (write-string "test not ok :compo" *standard-output*)
    (write-string (make-string 1 :initial-element #\newline) *standard-output*) ) )