;;;
;;; $compo Date: 2001/02/09 $
;;; This file is a copy of the file cm.lisp, made in the frame of the project compo.
;;; The intent of the modification is to allow the loading of both cm and compo.
;;; The modifications are signaled by a comment starting by $compo:
;;;
;;; This script uses the variables cm-path, cm-bin-path and cm-app-path
;;; to install Common Music.  The default values for these
;;; variables are:
;;;
;;; cm-path      ./../    [The parent directory of the directory
;;;                        containing this file.]
;;; cm-bin-path  ../bin/  [The bin directory under cm-path]
;;; cm-app-path  ../bin/  
;;;
;;; If you want to store binaries or the image somewhere else, edit the
;;; SETF line below and set the variables to whatever you want.  Be sure
;;; to include the final directory character in the directory strings
;;; you provide. The cm-app-path can contain file and extension
;;; components. If it doesn't the app name will default to something
;;; reasonable for your Lisp.
;;;
;;;
;;; $Revision: 1.3 $
;;; $Date: 2000/10/09 19:09:26 $

(proclaim '(special cm-path cm-bin-path cm-app-path cm-save))

; BL 01/26/2001 : loading of cmn
(load (make-pathname :host (pathname-host *load-pathname*)
                     :device (pathname-device *load-pathname*)
                     :directory `(,@(butlast (pathname-directory *load-pathname*)) "cmn")
                     :name "cmn-all"
                     :type "lisp" ))

; (SETF cm-path "/xyz/" cm-bin-path "/xyz/" cm-app-path "/xyz/cm.mem")

;;; ********************************************************************
;;; ********************************************************************
;;; ********************************************************************

#-(or mcl excl clisp cltl2)
(error "~%Common Music 2.0 runs in MCL, ACL and CLISP (cltl2).")

#-(or unix apple win32 microsoft-32)
(error "~%Common Music 2.0 runs on Macintosh, Unix or Windows")

#+(and excl microsoft-32)
(pushnew ':win32 *features*)

#+(and clisp unix pc386)
(pushnew ':linux *features*)

#+(and clisp unix (not pc386))
(unless (mismatch "IP" (machine-type) :end2 2)
  (pushnew ':sgi *features*))

(let ((cc? nil)
      #+mcl
      (ccl:*warn-if-redefine* nil)
      (tok #+apple #\: #+unix #\/ #+win32 #\\)
      (mi_d nil)
      app)

  #+excl
  (progn
    (excl:set-case-mode :case-insensitive-upper)
    (setf excl:*cltl1-in-package-compatibility-p* t)
    (setf comp:*cltl1-compile-file-toplevel-compatibility-p* t)
    (require :loop))

  (flet ((cc (f &optional dir
                &aux (b #+excl excl:*fasl-default-type*
                        #+mcl (pathname-type ccl:*.fasl-pathname*)
                        #+clisp "fas"))
           (let (s1 sf s2 bf)
             (if dir
               (setf sf (namestring
                         (merge-pathnames 
                          (format nil "~A.lisp" f)
                          (translate-logical-pathname dir)))
                     s1 sf
                     bf (namestring
                         (merge-pathnames
                          (format nil "~A.~A" f b)
                          (translate-logical-pathname "cm:bin;")))
                     s2 bf)
               (setf s1 (format nil "~A.lisp" f)
                     sf (logical-pathname s1)
                     s2 (format nil "cm:bin;~A.~A" (pathname-name sf) b)
                     bf (logical-pathname s2)))
             (if (or (not (probe-file bf))
                     (< (file-write-date bf) (file-write-date sf)))
               (progn
                 (format t "~%; Compiling ~S." s1)
                 (compile-file sf :output-file bf :verbose nil)
                 (setf cc? t)))
             (format t "~%; Loading ~S." s2)
             (load bf :verbose nil))))
    
    ;; provide default path values if unbound or nil.
    (if (and (boundp 'cm-path) cm-path)
      (progn
        (setf cm-path (namestring cm-path))
        (unless (char= tok (elt cm-path (1- (length cm-path))))
          (setf cm-path (format nil "~A~C" cm-path tok)))
        (setf cm-path (namestring (truename cm-path))))
      (let ((path #+mcl ccl:*loading-file-source-file*
                  #-mcl (truename *load-pathname*)))
        (setf cm-path
              (make-pathname :device (pathname-device path)
                             :host
                             (pathname-host path)
                             :directory
                             (butlast (pathname-directory path))))))
    (if (and (boundp 'cm-bin-path) cm-bin-path)
      (progn
        (setf cm-bin-path (namestring cm-bin-path))
        (unless (char= tok (elt cm-bin-path (1- (length cm-bin-path))))
          (setf cm-bin-path (format nil "~A~C" cm-bin-path tok)))
        (setf cm-bin-path (namestring (truename cm-bin-path)))
        (setf cm-bin-path
              `(("bin;*.*"
                 , (make-pathname
                    :device (pathname-device cm-bin-path)
                    :host (pathname-host cm-bin-path)
                    :directory (pathname-directory cm-bin-path)
                    :name ':wild :type ':wild)))))
      (setf cm-bin-path nil))
    (if (and (boundp 'cm-app-path) cm-app-path)
      ;; separate possible app name.ext from directory
      (let ((dir (make-pathname
                  :device (pathname-device cm-path)
                  :host (pathname-host cm-app-path)
                  :directory (pathname-directory cm-app-path))))
        (when (pathname-name cm-app-path)
          (setf app (enough-namestring cm-app-path dir)))
        (setf cm-app-path 
              (make-pathname :name ':wild :type ':wild :defaults dir)))
      (setf cm-app-path nil))
    
    (setf (logical-pathname-translations "cm")
          `( 
            ,@cm-bin-path 
            ("image;*.*"    , (or cm-app-path
                                  (logical-pathname "cm:bin;*.*")))
            ("help;*.*"     , (logical-pathname "cm:doc;*.*"))
            ("scripts;*.*"  , (logical-pathname "cm:etc;scripts;*.*"))
            ("examples;*.*" , (logical-pathname "cm:etc;examples;*.*"))
            ("contrib;*.*"  , (logical-pathname "cm:etc;contrib;*.*"))
            ("patches;*.*"  , (logical-pathname "cm:etc;patches;*.*"))
            #+MCL
            ("grace;*.*"    , (logical-pathname "cm:src;grace;*.*"))
            #+UNIX 
            ("tmp;*.*"      , (pathname "/tmp/*.*"))
            ("**;*.*" , (make-pathname 
                         :device (pathname-device cm-path)
                         :host (pathname-host cm-path)
                         :directory (append 
                                     (pathname-directory cm-path)
                                     '(:wild-inferiors))
                         :name ':wild :type ':wild))))
    
    ;; clisp's LOOP implementation is broken so load a working
    ;; version no matter what.
    #+clisp 
    (handler-bind ((t #'(lambda (c)
			  (when (find-restart 'continue)
			    (invoke-restart 'continue)))))
		  (cc "cm:src;loop"))

    #+mcl
    (unless (find ':loop *features*) ; may be added by clm or cmn
      (load "ccl:library;loop" :verbose t)
      (pushnew ':loop *features*))

    (cc "cm:src;pkg")

    ;; jeez this is really a hack now.
    (let ((check
           #+(and excl sgi) 
           (list
            (merge-pathnames "libmi_d.so"
                             (translate-logical-pathname
                              "cm:bin;"))) 
           #+(and mcl powerpc)
           (list (merge-pathnames "Mi_D Library PPC (MCL)"
                                  (ccl::findfolder 32768 :|extn|))
                 (merge-pathnames "cm:image;Mi_D Library PPC (MCL)")
                 )))
      (when check
        (loop 
          (dolist (p check)
            (if (probe-file p) (return (setf mi_d p))))
          (when (or mi_d
                    (not (y-or-n-p "Mi_D library ~S not found.~%~
                                    Type 'n' to skip Mi_D or else ~
                                    install and then type 'y': " 
                                   (namestring
                                    (translate-logical-pathname
                                     (first check))))))
            (return)))))

      (if mi_d 
        (progn 
          #+(and excl sgi)
          (load mi_d)
          (cc "mi_d" "cm:src;midi;"))
        (progn
          (cc "no-mi_d" "cm:src;midi;")))

    ;; always

    (cc "cm:src;utils")
    (cc "cm:src;compo-port")
    (cc "cm:src;clos")
    (cc "cm:src;objs")
    (cc "cm:src;map")
    (cc "cm:src;proc")
    (cc "cm:src;pat")
    (cc "cm:src;io")
    (cc "cm:src;tools")
    (cc "cm:src;anal")
    (cc "cm:src;midi;mm")
    (cc "cm:src;midi;mu")
    (cc "cm:src;midi;mf")
    (cc "cm:src;sco")

    (when mi_d
      (cc "cm:src;midi;mp")
      #+mcl
      (cc "cm:src;midi;mac;midi-menu"))

    ;; clm if loaded (?)
    (if (find-package :clm)
      (cc "cm:src;clm"))

    ;; cmn if loaded (?)
    (if (find-package :cmn)
      (cc "cm:src;cmn"))

    (cc "cm:src;vrml")
    (cc "cm:src;html")
    (load (logical-pathname "cm:etc;handlers.lisp"))
    (pushnew :cm *features*)
    (pushnew :cm-2 *features*)

    ; $compo Date: 2001/02/09 $
    ; loading of compo
    (load (make-pathname :host (pathname-host *load-pathname*)
                         :device (pathname-device *load-pathname*)
                         :directory `(,@(butlast
                                         (butlast (pathname-directory *load-pathname*)) )
                                      "compo-2.1" )
                     :name "setup"
                     :type "lisp" ))

    #+mcl 

; $compo Date: 2001/02/09 $
; Changing the initial package to :compo-cm
;    (ccl:eval-enqueue '(progn (in-package :cm)))
    (ccl:eval-enqueue '(progn (in-package :compo-cm)))
    (funcall (find-symbol "LOAD-CM-HELP" :cm))
    (if cc?
      (format t "~%~%; Sources were compiled. To save Common Music~%~
	         ; quit and restart Lisp, then reload compo-cm.lisp.")
      (when (or (not (boundp 'CM-SAVE)) CM-SAVE)
        (unless app

; $compo Date: 2001/02/09 $
; Changing the name of the image to "compo-2.1"
;          (setf app #+APPLE "Common Music" #+CLISP "cm.mem" 
          (setf app #+APPLE "compo-2.1" #+CLISP "compo.mem" 
                #+EXCL "compo.dxl"))
        #+mcl
        (when (and (boundp 'CM-SAVE)
                   (eq CM-SAVE ':application))
          (set (find-symbol "*EXCISE-COMPILER*" :cm) t))
        (funcall (find-symbol "SAVE-CM" :CM) app)))
    (values)))


