;;; **********************************************************************
;;; 
;;; Copyright (C) 2000 Heinrich Taube (taube@uiuc.edu) 
;;; 
;;; This program is free software; you can redistribute it and/or
;;; modify it under the terms of the GNU General Public License
;;; as published by the Free Software Foundation; either version 2
;;; of the License, or (at your option) any later version.
;;; 
;;; This program is distributed in the hope that it will be useful,
;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU General Public License for more details.
;;; 
;;; **********************************************************************
;;;
;;; $compo Date: 2001/02/09 $
;;; This file is a copy of the file cm-port.lisp, made in the frame of the project compo.
;;; The intent of the modification is to allow the loading of both cm and compo.
;;; The modifications are signaled by a comment starting by $compo:
;;;
;;; $Revision: 1.1.1.1 $
;;; $Date: 2000/09/13 17:00:00 $

(in-package :cm)

#-(OR CLTL2 EXCL MCL CLISP)
(eval-when (load compile eval) (error "Fix port.lisp for this Lisp."))

;;;
;;; Every port must define (or stub out) the following functions.
;;;
;;; arglist
;;; class-slots
;;; slot-definition-name
;;; slot-definition-initargs
;;; address-of (thing)                       Memory Loc of thing
;;; without-interrupts (&body body)          Execute body with priority.
;;; shell (&rest strings)                    Invoke Unix with command
;;; image-directory ()                       Directory of booted image.
;;; save-cm (path)                           Save CM image file.
;;;
;;; If the Lisp implementation supports multiprocessing, you should
;;; override the default definitions for these:
;;;
;;; process-run-function                     Run function in new process
;;; process-wait                             Wait until fn returns true
;;;

;;;
;;; evey os/lisp combination must define their file types.
;;;

(defconstant +source-type+ "lisp")

(defconstant +binary-type+ 
  #+excl excl:*fasl-default-type*
  #+mcl (pathname-type ccl:*.fasl-pathname*)
  #+clisp "fas")

#+unix
(defun unix-image-directory (name path)
  (if (or (char= (elt name 0) #\/)
          (char= (elt name 0) #\.))
    (let ((pos (position #\/ name :from-end t)))
      (if (not pos) "./" (subseq name 0 (1+ pos))))
    (loop with beg = 0 and len = (length path) 
          while (< beg len)
          for end = (or (position #\: path :start beg) len)
          for dir = (subseq path beg end)
          do (unless (char= (elt dir (1- (length dir))) #\/)
               (setf dir (concatenate 'string dir "/")))
          when (probe-file (make-pathname :defaults (pathname dir) 
                                          :name name))
          return dir
          do (setf beg (1+ end )))))


#-(or processes multiprocessing)            ; use one process.
(progn
  (defun process-run-function (options fn args)
    (declare (ignore options))
    (apply fn args))
  (defun process-wait (reason fn &rest args)
    (declare (ignore reason))
    (loop until (apply fn args)))

  (defun make-process (arg &rest keys)
    (declare (ignore arg keys))
    (error "Processes not implemented in this Lisp."))
  (defun process-preset (arg1 arg2 &rest keys)
    (declare (ignore arg1 arg2  keys))
    (error "Processes not implemented in this Lisp."))
  (defun process-enable (process)
    (declare (ignore process))
    (error "Processes not implemented in this Lisp."))
  (defun process-disable (process)
    (declare (ignore process))
    (error "Processes not implemented in this Lisp."))
  (defun process-kill (process)
    (declare (ignore process))
    (error "Processes not implemented in this Lisp."))
  )

;;;
;;; MCL Porting
;;;

#+MCL
(progn
    
  (import '(ccl:slot-definition-name ccl:slot-definition-initargs 
            ccl:class-direct-subclasses ccl:without-interrupts
            ccl:arglist ))
  
  (defun class-slots (class) 
    (ccl::class-instance-slots class))
  
  (defun address-of (x)
    (ccl:%address-of x))
  
  (defun macify-cm (dir) 
    (flet ((files (type) 
	     (directory (concatenate 'string dir "**:" type))) 
	   (dofiles (files create type) 
	     (dolist (f files) 
	       (ccl:set-mac-file-creator f create) 
	       (ccl:set-mac-file-type f type)))) 
      (dofiles (files "*.gif") ':moss "GIFf") 
      (dofiles (files "*.html") ':moss ':text) 
      (dofiles (files "*.lisp") ':ccl2 ':text) 
      (dofiles (files "*.cm") ':ccl2 ':text) 
      (dofiles (files "*.text") "ttxt" ':text) 
      (dofiles (files "README.*") "ttxt" ':text) 
      ))
  
  #+processes
  (eval-when (:load-toplevel :execute :compile-toplevel)
    (import '(ccl:process-run-function
	      ccl:process-wait ccl:process-enable
	      ccl:process-disable ccl:make-process
	      ccl:process-preset ccl:process-kill)))
  
  (defun shell (format &rest strings)
    (warn-user "MCL: can't SHELL ~S" 
               (apply #'format nil format strings)))
  
  (defun image-directory () (ccl:mac-default-directory))
  
  (defvar *cm-resources* nil)
  
  (defvar *excise-compiler* nil)
  
  (defun save-cm (pathname &optional
                           (defaults
                             (unlogify-pathname "cm:image;")))
    (setf pathname 
          (namestring (merge-pathnames pathname defaults)))
    (setf ccl::*inhibit-greeting* t)
    (setf ccl:*lisp-startup-functions*
          (append ccl:*lisp-startup-functions*
                  (list #'(lambda ()
                            (declare (special *midi-open-automatically*))

; $compo Date: 2001/02/09 $
; Setting :compo-cm rather than :cm as the default package
                            ;(setf *package* (find-package :cm))
                            (setf *package* (find-package :compo-cm))

                            (setf *readtable* *cm-readtable*)
                            (cminit)
                            (if *midi-open-automatically*
                              (ccl:eval-enqueue
                               '(let ((*standard-output* nil))
                                  (midi-open))))
                            ))))    
    (ccl:save-application pathname
                          :size '(#-clm #xA00000 #+clm #xC00000 #x500000)
                          :excise-compiler *excise-compiler*
                          :init-file nil
                          :resources *cm-resources*
                          ))
  )

;;;
;;; ACL Porting
;;;

#+EXCL
(progn
  
  (import '(excl:arglist))

  (import '(clos:slot-definition-name clos:class-slots
            clos:slot-definition-initargs clos:class-direct-subclasses))
  
  ;(defun macroexpand-all (form &optional env)
  ;  (clos::walk-form form env))
  
  (defun address-of (x)
    (excl::pointer-to-address x))

  #+multiprocessing
  (eval-when (:load-toplevel :execute :compile-toplevel)
    (import '(mp:process-run-function mp:process-wait mp:process-enable
              mp:process-disable mp:make-process
              mp:process-preset mp:process-kill)))
  
  (defmacro without-interrupts (&body body) 
    `(excl:without-interrupts ,@body))


  (defun shell (format &rest strings) 
    (excl:shell (apply #'format nil format strings)))
  
  (defun image-directory ()
    (unix-image-directory
     (or #+allegro-v5.0
	 (let ((pos (position "-I" sys::*command-line-arguments*
			      :test #'string=)))
	   (and pos (elt sys::*command-line-arguments* (1+ pos))))
	 (system:command-line-argument 0))
     (system:getenv "PATH")))
  
  (defun save-cm (pathname &optional (defaults
                                       (unlogify-pathname "cm:image;"))
                           &aux fn)
    (setf pathname 
          (namestring (merge-pathnames pathname defaults)))
    (terpri)
    (tell-user "Saving Common Music in ~S." pathname)
    (let ((tlp (loop for x in (logical-pathname-translations "cm")
                     collect (list (first x) (second x)))))
      (setf fn #'(lambda ()
                   (setf (logical-pathname-translations "cm") tlp)
                   (tpl:setq-default *readtable* *cm-readtable*)
; $compo Date: 2001/05/07 $
; Setting :compo-cm rather than :cm as the default package
;                   (tpl:setq-default *package* (find-package :cm))
                   (tpl:setq-default *package* (find-package :compo-cm))
                   (cminit)
                   )))
    
    (setf excl::*read-init-files* t )
    (push fn excl::*restart-actions*)
    (excl:dumplisp :name pathname))
  
  )

;;;
;;; CLISP Porting
;;;

#+CLISP
(progn

  (import '(system::arglist  ))

  (defun class-direct-subclasses (x)
    (declare (ignore x))
    (error "CLASS-DIRECT-SUBCLASSES not implemented in CLISP."))

  ;(defun macroexpand-all (form) 
  ;  (walker:macroexpand-all form #(nil nil)))

  (setf clos::*warn-if-gf-already-called* NIL)

  (defun class-slots (class)
    (clos::class-slots class))
 
  (defun slot-definition-name (slot)
    (clos::slotdef-name slot))

  (defun slot-definition-initargs (slot)
    (clos::slotdef-initargs slot))

  (import '(lisp:exit lisp:quit) :cm)

  (defun address-of (x)
    (sys::address-of x))

  (defmacro without-interrupts (&body body) `(progn ,@body)) 

  (defun shell (format &rest strings) 
    (lisp:shell (apply #'format nil format strings)))
  
  (defun image-directory () 
    (declare (special lisp::*image-pathname*))
    (and (boundp 'lisp::*image-pathname*) 
         lisp::*image-pathname*))
  
  (defun save-cm (pathname &optional
                           (defaults
                             (unlogify-pathname "cm:image;")))
    (setf pathname 
          (namestring (merge-pathnames pathname defaults)))
    (terpri)
    (tell-user "Saving Common Music in ~S." pathname)
    (lisp:saveinitmem pathname :quiet t
                      :init-function
                      #'(lambda ()
; $compo Date: 2001/05/07 $
; Setting :compo-cm rather than :cm as the default package
;                          (setf *package* (find-package :cm))
                          (setf *package* (find-package :compo-cm))
                          (setf *readtable* *cm-readtable*)
                          (cminit))))
  
  
  )

