;;; A Common Lisp implementation of the compo protocol Version 2
;;;
;;; Copyright (C) 2001  Bruno LARTILLOT
;;; 
;;; This program is free software; you can redistribute it and/or
;;; modify it under the terms of the GNU General Public License
;;; as published by the Free Software Foundation; either version 2
;;; of the License, or any later version.
;;;
;;; This program is distributed in the hope that it will be useful,
;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
;;; along with this program; if not, write to the Free Software
;;; Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

(in-package :note)

(setf *default-format* :text)

(defparameter *file* (make-pathname :host *host*
                                    :device *device* 
                                    :directory `(,@*compo-root* "doc" "dev")
                                    :name "compo"
                                    :type "txt" ))

(with-open-file (file *file*
                      :direction :output
                      :if-exists :supersede )
  
  (write-string "Package :compo" file)
  (write-string (make-string 1 :initial-element #\newline) file)
  (write-string "--------------" file)
  (write-string (make-string 2 :initial-element #\newline) file)
  
  (write-string "General tools" file)
  (write-string (make-string 1 :initial-element #\newline) file)
  (write-string "-------------" file)
  (write-string (make-string 2 :initial-element #\newline) file)
  (write-string (format-doc (documentation 'circar 'function)) file)
  (write-string (format-doc (documentation 'circdr 'function)) file)
  (write-string (format-doc (documentation 'format-doc 'function)) file)
  (write-string (format-doc (documentation 'make-and-load 'function)) file)
  (write-string (format-doc (documentation 'mydeftype 'function)) file)
  
  (write-string "Compositions" file)
  (write-string (make-string 1 :initial-element #\newline) file)
  (write-string "------------" file)
  (write-string (make-string 2 :initial-element #\newline) file)
  (write-string (format-doc (documentation (find-class 'abstract-compo))) file)
  (write-string (format-doc (documentation (find-class 'compo))) file)
  (write-string (format-doc (documentation (find-class 'ccompo))) file)
  (write-string (format-doc (documentation (find-class 'context-item))) file)

  (write-string "Comparators and copy constructors" file)
  (write-string (make-string 1 :initial-element #\newline) file)
  (write-string "---------------------------------" file)
  (write-string (make-string 2 :initial-element #\newline) file)
  (write-string (format-doc (documentation #'is-equal)) file)
  (write-string (format-doc
                 (documentation (find-method #'is-equal
                                             ()
                                             (list (find-class 't)
                                                   (find-class 't) ) )) )
                file )
  (write-string (format-doc
                 (documentation (find-method #'is-equal
                                             ()
                                             (list (find-class 'cons)
                                                   (find-class 'cons) ) )) )
                file )
  (write-string (format-doc
                 (documentation (find-method #'is-equal
                                             ()
                                             (list (find-class 'standard-object)
                                                   (find-class 'standard-object) ) )) )
                file )
  (write-string (format-doc
                 (documentation (find-method #'is-equal
                                             ()
                                             (list (find-class 'abstract-compo)
                                                   (find-class 'abstract-compo) ) )) )
                file )
  (write-string (format-doc (documentation #'compo-lessp)) file)
  (write-string (format-doc
                 (documentation (find-method #'compo-lessp
                                             ()
                                             (list (find-class 'abstract-compo)
                                                   (find-class 'abstract-compo) ) )) )
                file )
  (write-string (format-doc (documentation #'clone)) file)
  (write-string (format-doc
                 (documentation (find-method #'clone
                                             ()
                                             (list (find-class 't)) )) )
                file )
  (write-string (format-doc
                 (documentation (find-method #'clone
                                             ()
                                             (list (find-class 'cons)) )) )
                file )
  (write-string (format-doc
                 (documentation (find-method #'clone
                                             ()
                                             (list (find-class 'standard-object)) )) )
                file )
  (write-string (format-doc (documentation #'clone-slots)) file)
  (write-string (format-doc
                 (documentation (find-method #'clone-slots
                                             ()
                                             (list (find-class 't)
                                                   (find-class 't) ) )) )
                file )
  (write-string (format-doc
                 (documentation (find-method #'clone-slots
                                             ()
                                             (list (find-class 'abstract-compo)
                                                   (find-class 'abstract-compo) ) )) )
                file )
  
  (write-string "Realization of compositions" file)
  (write-string (make-string 1 :initial-element #\newline) file)
  (write-string "---------------------------" file)
  (write-string (make-string 2 :initial-element #\newline) file)
  (write-string (format-doc (documentation 'realize 'function)) file)
  (write-string (format-doc (documentation #'nrealize)) file)
  (write-string (format-doc
                 (documentation (find-method #'nrealize
                                             ()
                                             (list (find-class 'abstract-compo)) )) )
                file )
  (write-string (format-doc (documentation #'realize-using-context-item)) file)
  (write-string (format-doc
                 (documentation (find-method #'realize-using-context-item
                                             ()
                                             (list (find-class 'context-item)
                                                   (find-class 'abstract-compo) ) )) )
                file )
  
  (write-string "contexts items" file)
  (write-string (make-string 1 :initial-element #\newline) file)
  (write-string "--------------" file)
  (write-string (make-string 2 :initial-element #\newline) file)
  (write-string (format-doc (documentation (find-class 'atomization))) file)
  (write-string (format-doc
                 (documentation (find-method #'realize-using-context-item
                                             ()
                                             (list (find-class 'atomization)
                                                   (find-class 'compo) ) )) )
                file )
  (write-string (format-doc (documentation (find-class 'coercion))) file)
  (write-string (format-doc
                 (documentation (find-method #'realize-using-context-item
                                             ()
                                             (list (find-class 'coercion)
                                                   (find-class 'compo) ) )) )
                file )
  (write-string (format-doc (documentation (find-class 'evaluation))) file)
  (write-string (format-doc
                 (documentation (find-method #'realize-using-context-item
                                             ()
                                             (list (find-class 'evaluation)
                                                   (find-class 'compo) ) )) )
                file )
  (write-string (format-doc (documentation (find-class 'granulation))) file)
  (write-string (format-doc
                 (documentation (find-method #'realize-using-context-item
                                             ()
                                             (list (find-class 'granulation)
                                                   (find-class 'compo) ) )) )
                file )
  (write-string (format-doc (documentation (find-class 'integration))) file)
  (write-string (format-doc
                 (documentation (find-method #'realize-using-context-item
                                             ()
                                             (list (find-class 'integration)
                                                   (find-class 'compo) ) )) )
                file )
  (write-string (format-doc (documentation (find-class 'realization))) file)
  (write-string (format-doc
                 (documentation (find-method #'is-equal
                                             ()
                                             (list (find-class 'realization)
                                                   (find-class 'realization) ) )) )
                file )
  (write-string (format-doc
                 (documentation (find-method #'clone-slots
                                             ()
                                             (list (find-class 'realization)
                                                   (find-class 'realization) ) )) )
                file )
  (write-string (format-doc
                 (documentation (find-method #'realize-using-context-item
                                             ()
                                             (list (find-class 'realization)
                                                   (find-class 'abstract-compo) ) )) )
                file )
  (write-string (format-doc (documentation (find-class 'recursion))) file)
  (write-string (format-doc
                 (documentation (find-method #'realize-using-context-item
                                             ()
                                             (list (find-class 'recursion)
                                                   (find-class 'compo) ) )) )
                file )
  (write-string (format-doc (documentation (find-class 'selection))) file)
  (write-string (format-doc
                 (documentation (find-method #'realize-using-context-item
                                             ()
                                             (list (find-class 'selection)
                                                   (find-class 'compo) ) )) )
                file )
  (write-string (format-doc (documentation (find-class 'sorting))) file)
  (write-string (format-doc
                 (documentation (find-method #'realize-using-context-item
                                             ()
                                             (list (find-class 'sorting)
                                                   (find-class 'compo) ) )) )
                file )
  (write-string (format-doc (documentation (find-class 'transformation))) file)
  (write-string (format-doc
                 (documentation (find-method #'realize-using-context-item
                                             ()
                                             (list (find-class 'transformation)
                                                   (find-class 'compo) ) )) )
                file )
  (write-string (format-doc (documentation (find-class 'unicity))) file)
  (write-string (format-doc
                 (documentation (find-method #'realize-using-context-item
                                             ()
                                             (list (find-class 'unicity)
                                                   (find-class 'compo) ) )) )
                file )
  
  (write-string "coercion specifiers" file)
  (write-string (make-string 1 :initial-element #\newline) file)
  (write-string "-------------------" file)
  (write-string (make-string 2 :initial-element #\newline) file)
  (write-string (format-doc (documentation 'coerce-value 'function)) file)
  (write-string (format-doc (documentation 'closestc 'function)) file)
  
  (write-string "redefinable realization behaviour" file)
  (write-string (make-string 1 :initial-element #\newline) file)
  (write-string "---------------------------------" file)
  (write-string (make-string 2 :initial-element #\newline) file)
  (write-string (format-doc (documentation #'coerce-compo)) file)
  (write-string (format-doc
                 (documentation (find-method #'coerce-compo
                                             ()
                                             (list (find-class 'compo)
                                                   (find-class 't) ) )) )
                file )
  (write-string (format-doc (documentation #'evaluate)) file)
  (write-string (format-doc
                 (documentation (find-method #'evaluate
                                             ()
                                             (list (find-class 'compo)
                                                   (find-class 't)
                                                   (find-class 't) ) )) )
                file )
  (write-string (format-doc (documentation #'granulate-compo)) file)
  (write-string (format-doc
                 (documentation (find-method #'granulate-compo
                                             ()
                                             (list (find-class 'compo) ) )) )
                file )
  (write-string (format-doc (documentation #'integrate-compo)) file)
  (write-string (format-doc
                 (documentation (find-method #'integrate-compo
                                             ()
                                             (list (find-class 'compo) ) )) )
                file )
  (write-string (format-doc (documentation #'make-constant)) file)
  (write-string (format-doc
                 (documentation (find-method #'make-constant
                                             ()
                                             (list (find-class 'abstract-compo)
                                                   (find-class 'context-item) ) )) )
                file )
  (write-string (format-doc (documentation #'select-compo)) file)
  (write-string (format-doc
                 (documentation (find-method #'select-compo
                                             ()
                                             (list (find-class 'compo)) )) )
                file )
  (write-string (format-doc (documentation #'transform)) file)
  (write-string (format-doc
                 (documentation (find-method #'transform
                                             ()
                                             (list (find-class 'compo)
                                                   (find-class 't) ) )) )
                file )
  
  (write-string "contexts" file)
  (write-string (make-string 1 :initial-element #\newline) file)
  (write-string "--------" file)
  (write-string (make-string 2 :initial-element #\newline) file)
  (write-string (format-doc (documentation (find-class 'standard-context))) file)

  (write-string "syntactic sugar" file)
  (write-string (make-string 1 :initial-element #\newline) file)
  (write-string "---------------" file)
  (write-string (make-string 2 :initial-element #\newline) file)
  (write-string (format-doc (documentation 'key->val 'function)) file)
  (write-string (format-doc (documentation 'quote-expr 'function)) file)
  (write-string (format-doc (documentation 'normalize-compo 'function)) file)
  (write-string (format-doc (documentation #'specialized-normalize)) file)
  (write-string (format-doc
                 (documentation (find-method #'specialized-normalize
                                             ()
                                             (list (find-class 'abstract-compo)
                                                   (find-class 't)
                                                   (find-class 't)
                                                   (find-class 't) ) )) )
                file )
  (write-string (format-doc (documentation 'sugar-compo 'function)) file)
  (write-string (format-doc
                 (documentation (find-method #'print-object
                                             ()
                                             (list (find-class 'abstract-compo)
                                                   (find-class 't) ) )) )
                file )
  (write-string (format-doc (documentation #'sub-print)) file)
  (write-string (format-doc
                 (documentation (find-method #'sub-print
                                             ()
                                             (list (find-class 't)
                                                   (find-class 't) 
                                                   (find-class 't) ) )) )
                file )
  (write-string (format-doc
                 (documentation (find-method #'sub-print
                                             ()
                                             (list (find-class 'abstract-compo)
                                                   (find-class 't) 
                                                   (find-class 't) ) )) )
                file )
  (write-string (format-doc (documentation #'specialized-print)) file)
  (write-string (format-doc
                 (documentation (find-method #'specialized-print
                                             ()
                                             (list (find-class 'abstract-compo)
                                                   (find-class 't) 
                                                   (find-class 't) ) )) )
                file )
  (write-string (format-doc (documentation 'compo::pprint-compo 'function)) file)
  (write-string (format-doc (documentation #'sub-pprint)) file)
  (write-string (format-doc
                 (documentation (find-method #'sub-pprint
                                             ()
                                             (list (find-class 't)
                                                   (find-class 't) 
                                                   (find-class 't) ) )) )
                file )
  (write-string (format-doc
                 (documentation (find-method #'sub-pprint
                                             ()
                                             (list (find-class 'abstract-compo)
                                                   (find-class 't) 
                                                   (find-class 't) ) )) )
                file )

  (write-string "Package :note" file)
  (write-string (make-string 1 :initial-element #\newline) file)
  (write-string "-------------" file)
  (write-string (make-string 2 :initial-element #\newline) file)
  
  (write-string "Notes" file)
  (write-string (make-string 1 :initial-element #\newline) file)
  (write-string "-----" file)
  (write-string (make-string 2 :initial-element #\newline) file)
  (write-string (format-doc (documentation (find-class 'abstract-note))) file)
  (write-string (format-doc (documentation (find-class 'cnote))) file)
  (write-string (format-doc (documentation (find-class 'note))) file)
  (write-string (format-doc (documentation (find-class 'fermata-repeat-end))) file)
  (write-string (format-doc (documentation (find-class 'fermata))) file)
  (write-string (format-doc (documentation (find-class 'lyrics))) file)
  (write-string (format-doc (documentation (find-class 'repeat-end))) file)

  (write-string "Pitches" file)
  (write-string (make-string 1 :initial-element #\newline) file)
  (write-string "-------" file)
  (write-string (make-string 2 :initial-element #\newline) file)
  (write-string (format-doc (documentation '*default-syntax* 'variable)) file)
  (write-string (format-doc (documentation 'intern-temperament 'function)) file)
  (write-string (format-doc (documentation '*compo-temperament* 'variable)) file)
  (write-string (format-doc (documentation '*pythagorician-temperament* 'variable)) file)
  (write-string (format-doc (documentation '*equal-temperament* 'variable)) file)
  (write-string (format-doc (documentation '*default-temperament* 'variable)) file)
  (write-string (format-doc (documentation 'normalize-pitch 'function)) file)
  (write-string (format-doc (documentation 'denormalize-pitch 'function)) file)
  (write-string (format-doc (documentation 'pitchp 'function)) file)
  (write-string (format-doc (documentation 'itp 'function)) file)
  (write-string (format-doc (documentation 'itei 'function)) file)
  (write-string (format-doc (documentation 'pti 'function)) file)
  (write-string (format-doc (documentation 'ptep 'function)) file)
  (write-string (format-doc (documentation 'naturalp 'function)) file)
  (write-string (format-doc (documentation 'sharpp 'function)) file)
  (write-string (format-doc (documentation 'flatp 'function)) file)
  (write-string (format-doc (documentation 'double-sharp-p 'function)) file)
  (write-string (format-doc (documentation 'double-flat-p 'function)) file)
  (write-string (format-doc (documentation 'funcptf 'function)) file)
  (write-string (format-doc (documentation 'ptf-eq-440 'function)) file)
  (write-string (format-doc (documentation 'ptf-py-440 'function)) file)

  (write-string "Cleaves" file)
  (write-string (make-string 1 :initial-element #\newline) file)
  (write-string "-------" file)
  (write-string (make-string 2 :initial-element #\newline) file)
  (write-string (format-doc (documentation 'cleavep 'function)) file)
  (write-string (format-doc (documentation 'ntoc 'function)) file)
  (write-string (format-doc (documentation 'ntoev 'function)) file)
  (write-string (format-doc (documentation 'cton 'function)) file)

  (write-string "Durations" file)
  (write-string (make-string 1 :initial-element #\newline) file)
  (write-string "-------" file)
  (write-string (make-string 2 :initial-element #\newline) file)
  (write-string (format-doc (documentation 'durationp 'function)) file)
  (write-string (format-doc (documentation 'ntod 'function)) file)
  (write-string (format-doc (documentation 'dton 'function)) file)
  
  (write-string "Coercion specifiers" file)
  (write-string (make-string 1 :initial-element #\newline) file)
  (write-string "-------------------" file)
  (write-string (make-string 2 :initial-element #\newline) file)
  (write-string (format-doc (documentation 'mode 'function)) file)
  
  (write-string "redefined realization behaviour" file)
  (write-string (make-string 1 :initial-element #\newline) file)
  (write-string "-------------------------------" file)
  (write-string (make-string 2 :initial-element #\newline) file)
  (write-string (format-doc
                 (documentation (find-method #'clone-slots
                                             ()
                                             (list (find-class 'abstract-note)
                                                   (find-class 'abstract-note) ) )) )
                file )
  (write-string (format-doc
                 (documentation (find-method #'coerce-compo
                                             ()
                                             (list (find-class 'note)
                                                   (find-class 't) ) )) )
                file )
  (write-string (format-doc
                 (documentation (find-method #'compo-lessp
                                             ()
                                             (list (find-class 'abstract-note)
                                                   (find-class 'abstract-note) ) )) )
                file )
  (write-string (format-doc
                 (documentation (find-method #'evaluate
                                             ()
                                             (list (find-class 'note)
                                                   (find-class 't)
                                                   (find-class 't) ) )) )
                file )
  (write-string (format-doc
                 (documentation (find-method #'integrate-compo
                                             ()
                                             (list (find-class 'note) ) )) )
                file )
  (write-string (format-doc
                 (documentation (find-method #'is-equal
                                             ()
                                             (list (find-class 'abstract-note)
                                                   (find-class 'abstract-note) ) )) )
                file )
  (write-string (format-doc
                 (documentation (find-method #'make-constant
                                             ()
                                             (list (find-class 'abstract-note)
                                                   (find-class 'context-item) ) )) )
                file )
  (write-string (format-doc
                 (documentation (find-method #'select-compo
                                             ()
                                             (list (find-class 'lyrics) ) )) )
                file )

  (write-string "syntactic sugar" file)
  (write-string (make-string 1 :initial-element #\newline) file)
  (write-string "---------------" file)
  (write-string (make-string 2 :initial-element #\newline) file)
  (write-string (format-doc (documentation 'sugar-note 'function)) file)
  nil )