;;; A Common Lisp implementation of the compo protocol Version 2
;;;
;;; Package :note
;;;
;;; Copyright (C) 2001  Bruno LARTILLOT
;;; 
;;; This program is free software; you can redistribute it and/or
;;; modify it under the terms of the GNU General Public License
;;; as published by the Free Software Foundation; either version 2
;;; of the License, or any later version.
;;;
;;; This program is distributed in the hope that it will be useful,
;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
;;; along with this program; if not, write to the Free Software
;;; Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

(in-package :note)

(defmethod integrate-compo ((note note))

"Primary method
   integrate-compo specialized on the note type
Behaviour
   The slots 'hei', 'voi' and 'dyn' in the note have their value set to their neutral
   value (0, 0 and 1 respectively).
   The slot 'pos' in the note is set to the minimum position from the subnotes of the
   notes.
   The slot 'dur' in the note is set to the maximum sum of position and duration from
   the subcompositions of the note minus the new computed position of the note.
   The note is returned as a result."

  (with-slots (subs) note
    (setf (hei note) 0)
    (setf (voi note) 0)
    (setf (dyn note) 1)
    (when subs
      (let ((min-pos most-positive-fixnum)
            (max-dur 0))
        (mapc #'(lambda (sub)
                  (let* ((pos (pos sub))
                         (dur (dur sub))
                         (sum (+ pos dur)))
                    (when (< pos min-pos)
                      (setf min-pos pos))
                    (when (> sum max-dur)
                      (setf max-dur sum))))
              subs)
        (setf (pos note) 
              min-pos)
        (setf (dur note) 
              (- max-dur min-pos) ) ) ) )
  note )