;;; A Common Lisp implementation of the compo protocol Version 2
;;;
;;; Package :note
;;;
;;; Copyright (C) 2001  Bruno LARTILLOT
;;; 
;;; This program is free software; you can redistribute it and/or
;;; modify it under the terms of the GNU General Public License
;;; as published by the Free Software Foundation; either version 2
;;; of the License, or any later version.
;;;
;;; This program is distributed in the hope that it will be useful,
;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
;;; along with this program; if not, write to the Free Software
;;; Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

(in-package :note)

(defmethod specialized-normalize ((spec abstract-note) class l defaults
                                  &rest restargs
                                  &key temperament &allow-other-keys )

  (or
   (call-next-method)
   (cond
    ((eq (car l) :chord)
     (apply #'normalize-compo `(:juxt ,@(cdr l)) class spec `(:pos-mod :super ,@defaults) restargs) )
    ((eq (car l) :hei)
     (list* :hei (key->val (quote-expr (let ((hei (check-hei (cadr l))))
                                         (when (eq hei :abort) (abort)) hei ))
                           #'(lambda (a) (pti (normalize-pitch a) :temperament temperament)) )
            (apply #'normalize-compo (cddr l) class spec defaults restargs) ) )
    ((eq (car l) :dur)
     (list* :dur (key->val (quote-expr (let ((dur (check-dur (cadr l))))
                                         (when (eq dur :abort) (abort)) dur ))
                           #'(lambda (a) (dton a)))
            (apply #'normalize-compo (cddr l) class spec defaults restargs) ) )
    ((eq (car l) :pos)
     (list* :pos (quote-expr (let ((pos (check-pos (cadr l))))
                               (when (eq pos :abort) (abort)) pos ))
            (apply #'normalize-compo (cddr l) class spec defaults restargs)) )
    ((eq (car l) :pos-mod)
     (list* :pos-mod (let ((pos-mod (check-pos-mod (cadr l))))
                       (when (eq pos-mod :abort) (abort)) pos-mod )
            (apply #'normalize-compo (cddr l) class spec defaults restargs)) )
    ((eq (car l) :voi)
     (list* :voi (key->val (quote-expr (let ((voi (check-voi (cadr l))))
                                         (when (eq voi :abort) (abort)) voi ) )
                           #'(lambda (a) (cton a)) )
            (apply #'normalize-compo (cddr l) class spec defaults restargs) ) )
    ((eq (car l) :dyn)
     (list* :dyn (quote-expr (let ((dyn (check-dyn (cadr l))))
                                         (when (eq dyn :abort) (abort)) dyn ))
            (apply #'normalize-compo (cddr l) class spec defaults restargs) ) )
    ((eq (car l) :coerce-hei)
     (list* :coerce-hei
            (key->val (quote-expr (let ((val (check-hei-coercer (cadr l))))
                                    (when (eq val :abort) (abort)) val ))
                      #'(lambda (a) (pti (normalize-pitch a) :temperament temperament)) )
            (apply #'normalize-compo (cddr l) class spec defaults restargs) ) )
    ((eq (car l) :coerce-dur)
     (list* :coerce-dur
            (key->val (quote-expr (let ((val (check-dur-coercer (cadr l))))
                                    (when (eq val :abort) (abort)) val ))
                      #'(lambda (a) (dton a)) )
            (apply #'normalize-compo (cddr l) class spec defaults restargs) ) )
    ((eq (car l) :coerce-pos)
     (list* :coerce-pos (quote-expr (let ((val (check-pos-coercer (cadr l))))
                                      (when (eq val :abort) (abort)) val ))
            (apply #'normalize-compo (cddr l) class spec defaults restargs) ) )
    ((eq (car l) :coerce-voi)
     (list* :coerce-voi
            (key->val (quote-expr (let ((val (check-voi-coercer (cadr l))))
                                    (when (eq val :abort) (abort)) val ))
                      #'(lambda (a) (cton a)) )
            (apply #'normalize-compo (cddr l) class spec defaults restargs) ) )
    ((eq (car l) :coerce-dyn)
     (list* :coerce-dyn (quote-expr (let ((val (check-dyn-coercer (cadr l))))
                                      (when (eq val :abort) (abort)) val ))
            (apply #'normalize-compo (cddr l) class spec defaults restargs) ) )
    ((keywordp (car l))
     (let ((val (check-parameter-key (car l))))
       (when (eq val :abort) (abort))
       (cond
        ((pitchp val)
         (list* :hei (key->val val
                               #'(lambda (a) (pti (normalize-pitch a)
                                                  :temperament temperament )) )
                (apply #'normalize-compo (cdr l) class spec defaults restargs) ) )
        ((eq val :rest)
         (list* :hei nil
                (apply #'normalize-compo (cdr l) class spec defaults restargs) ) )
        ((durationp val)
         (list* :dur (key->val val #'(lambda (a) (dton a)))
                (apply #'normalize-compo (cdr l) class spec defaults restargs) ) )
        ((or (eq val :abs) (eq val :juxt) (eq val :super))
         (list* :pos-mod val
                (apply #'normalize-compo (cdr l) class spec defaults restargs) ) )
        ((cleavep val)
         (list* :voi (key->val val #'(lambda (a) (cton a)))
                (apply #'normalize-compo (cdr l) class spec defaults restargs) ) ) ) ) ) ) ) )