;;; A Common Lisp implementation of the compo protocol Version 2
;;;
;;; Package :note
;;;
;;; Copyright (C) 2001  Bruno LARTILLOT
;;; 
;;; This program is free software; you can redistribute it and/or
;;; modify it under the terms of the GNU General Public License
;;; as published by the Free Software Foundation; either version 2
;;; of the License, or any later version.
;;;
;;; This program is distributed in the hope that it will be useful,
;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
;;; along with this program; if not, write to the Free Software
;;; Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

(in-package :note)

(defgeneric specialized-help (self))

(defmethod specialized-help ((self t))
  (let ((cr (make-string 1 :initial-element #\newline)))
    (write-string *note*)
    (write-string cr)
    (write-string *class-name*)
    (write-string cr)
    (write-string *note-complement*)
    (write-string cr)
    (write-string *comment*)
    (write-string cr)
    (write-string *parameters*)
    (write-string cr)
    (write-string *parameter-couple*)
    (write-string cr)
    (write-string *hei-couple*)
    (write-string cr)
    (write-string *dur-couple*)
    (write-string cr)
    (write-string *pos-mod-couple*)
    (write-string cr)
    (write-string *pos-couple*)
    (write-string cr)
    (write-string *voi-couple*)
    (write-string cr)
    (write-string *dyn-couple*)
    (write-string cr)
    (write-string *hei-coercer-couple*)
    (write-string cr)
    (write-string *dur-coercer-couple*)
    (write-string cr)
    (write-string *pos-coercer-couple*)
    (write-string cr)
    (write-string *voi-coercer-couple*)
    (write-string cr)
    (write-string *dyn-coercer-couple*)
    (write-string cr) )
  (values) )

(defmethod specialized-help ((self (eql :coerce-dur)))
  (let ((cr (make-string 1 :initial-element #\newline)))
    (write-string *dur-coercer*)
    (write-string cr)
    (write-string *dur-call*)
    (write-string cr)
    (write-string *coercer-specifier-name*)
    (write-string cr)
    (write-string *dur-value*)
    (write-string cr)
    (if (eq *default-syntax* :english)
      (progn
        (write-string *eng-dur-key*)
        (write-string cr) )
      (progn
        (write-string *lat-dur-key*)
        (write-string cr) ) )
    (write-string *common-lisp-number*)
    (write-string cr)
    (write-string *compo-lexical-variable*)
    (write-string cr)
    (write-string *evaluable-dur*)
    (write-string cr)
    (write-string *dur-operator*)
    (write-string cr)
    (write-string *operator-name*)
    (write-string cr) )
  (values) )

(defmethod specialized-help ((self (eql :dur)))
  (let ((cr (make-string 1 :initial-element #\newline)))
    (write-string *dur-value*)
    (write-string cr)
    (if (eq *default-syntax* :english)
      (progn
        (write-string *eng-dur-key*)
        (write-string cr) )
      (progn
        (write-string *lat-dur-key*)
        (write-string cr) ) )
    (write-string *common-lisp-number*)
    (write-string cr)
    (write-string *compo-lexical-variable*)
    (write-string cr)
    (write-string *evaluable-dur*)
    (write-string cr)
    (write-string *dur-operator*)
    (write-string cr)
    (write-string *operator-name*)
    (write-string cr) )
  (values) )

(defmethod specialized-help ((self (eql :coerce-dyn)))
  (let ((cr (make-string 1 :initial-element #\newline)))
    (write-string *dyn-coercer*)
    (write-string cr)
    (write-string *call*)
    (write-string cr)
    (write-string *coercer-specifier-name*)
    (write-string cr)
    (write-string *value*)
    (write-string cr)
    (write-string *common-lisp-number*)
    (write-string cr)
    (write-string *compo-lexical-variable*)
    (write-string cr)
    (write-string *evaluable*)
    (write-string cr)
    (write-string *operator*)
    (write-string cr)
    (write-string *operator-name*)
    (write-string cr) )
  (values) )

(defmethod specialized-help ((self (eql :dyn)))
  (let ((cr (make-string 1 :initial-element #\newline)))
    (write-string *value*)
    (write-string cr)
    (write-string *common-lisp-number*)
    (write-string cr)
    (write-string *compo-lexical-variable*)
    (write-string cr)
    (write-string *evaluable*)
    (write-string cr)
    (write-string *operator*)
    (write-string cr)
    (write-string *operator-name*)
    (write-string cr) )
  (values) )

(defmethod specialized-help ((self (eql :coerce-hei)))
  (let ((cr (make-string 1 :initial-element #\newline)))
    (write-string *hei-coercer*)
    (write-string cr)
    (write-string *hei-call*)
    (write-string cr)
    (write-string *coercer-specifier-name*)
    (write-string cr)
    (write-string *hei-value*)
    (write-string cr)
    (write-string *hei-key*)
    (write-string cr)
    (if (eq *default-syntax* :english)
      (progn
        (write-string *eng-hei-elementary-key*)
        (write-string cr) )
      (progn
        (write-string *lat-hei-elementary-key*)
        (write-string cr) ) )
    (write-string *common-lisp-number*)
    (write-string cr)
    (write-string *compo-lexical-variable*)
    (write-string cr)
    (write-string *evaluable-hei*)
    (write-string cr)
    (write-string *hei-operator*)
    (write-string cr)
    (write-string *operator-name*)
    (write-string cr) )
  (values) )

(defmethod specialized-help ((self (eql :hei)))
  (let ((cr (make-string 1 :initial-element #\newline)))
    (write-string *hei-value*)
    (write-string cr)
    (write-string *hei-key*)
    (write-string cr)
    (if (eq *default-syntax* :english)
      (progn
        (write-string *eng-hei-elementary-key*)
        (write-string cr) )
      (progn
        (write-string *lat-hei-elementary-key*)
        (write-string cr) ) )
    (write-string *common-lisp-number*)
    (write-string cr)
    (write-string *compo-lexical-variable*)
    (write-string cr)
    (write-string *evaluable-hei*)
    (write-string cr)
    (write-string *hei-operator*)
    (write-string cr)
    (write-string *operator-name*)
    (write-string cr) )
  (values) )

(defmethod specialized-help ((self (eql :parameter-key)))
  (let ((cr (make-string 1 :initial-element #\newline)))
    (write-string *parameter-key*)
    (write-string cr)
    (write-string *hei-key*)
    (write-string cr)
    (if (eq *default-syntax* :english)
      (progn
        (write-string *eng-hei-elementary-key*)
        (write-string cr) )
      (progn
        (write-string *lat-hei-elementary-key*)
        (write-string cr) ) )
    (if (eq *default-syntax* :english)
      (progn
        (write-string *eng-dur-key*)
        (write-string cr) )
      (progn
        (write-string *lat-dur-key*)
        (write-string cr) ) )
    (write-string *pos-mod-key*)
    (write-string cr)
    (write-string *voi-key*)
    (write-string cr) )
  (values) )

(defmethod specialized-help ((self (eql nil)))
  (specialized-help :keyword) )

(defmethod specialized-help ((self (eql :coerce-pos)))
  (let ((cr (make-string 1 :initial-element #\newline)))
    (write-string *pos-coercer*)
    (write-string cr)
    (write-string *call*)
    (write-string cr)
    (write-string *coercer-specifier-name*)
    (write-string cr)
    (write-string *value*)
    (write-string cr)
    (write-string *common-lisp-number*)
    (write-string cr)
    (write-string *compo-lexical-variable*)
    (write-string cr)
    (write-string *evaluable*)
    (write-string cr)
    (write-string *operator*)
    (write-string cr)
    (write-string *operator-name*)
    (write-string cr) )
  (values) )

(defmethod specialized-help ((self (eql :pos-mod)))
  (let ((cr (make-string 1 :initial-element #\newline)))
    (write-string *pos-mod-key*)
    (write-string cr) )
  (values) )

(defmethod specialized-help ((self (eql :pos)))
  (let ((cr (make-string 1 :initial-element #\newline)))
    (write-string *value*)
    (write-string cr)
    (write-string *common-lisp-number*)
    (write-string cr)
    (write-string *compo-lexical-variable*)
    (write-string cr)
    (write-string *evaluable*)
    (write-string cr)
    (write-string *operator*)
    (write-string cr)
    (write-string *operator-name*)
    (write-string cr) )
  (values) )

(defmethod specialized-help ((self (eql :coerce-voi)))
  (let ((cr (make-string 1 :initial-element #\newline)))
      (write-string *voi-coercer*)
      (write-string cr)
      (write-string *voi-call*)
      (write-string cr)
      (write-string *coercer-specifier-name*)
      (write-string cr)
      (write-string *voi-value*)
      (write-string cr)
      (write-string *voi-key*)
      (write-string cr)
      (write-string *common-lisp-number*)
      (write-string cr)
      (write-string *compo-lexical-variable*)
      (write-string cr)
      (write-string *evaluable-voi*)
      (write-string cr)
      (write-string *voi-operator*)
      (write-string cr)
      (write-string *operator-name*)
      (write-string cr) )
  (values) )

(defmethod specialized-help ((self (eql :voi)))
  (let ((cr (make-string 1 :initial-element #\newline)))
      (write-string *voi-value*)
      (write-string cr)
      (write-string *voi-key*)
      (write-string cr)
      (write-string *common-lisp-number*)
      (write-string cr)
      (write-string *compo-lexical-variable*)
      (write-string cr)
      (write-string *evaluable-voi*)
      (write-string cr)
      (write-string *voi-operator*)
      (write-string cr)
      (write-string *operator-name*)
      (write-string cr) )
  (values) )

(defmethod specialized-help ((self (eql :subs)))
  (let ((cr (make-string 1 :initial-element #\newline)))
      (write-string *sub-spec*)
      (write-string cr)
      (write-string *declaration*)
      (write-string cr)
      (write-string *reference*)
      (write-string cr)
      (write-string *symbol*)
      (write-string cr)
      (write-string *multiple*)
      (write-string cr)
      (write-string *anonym*)
      (write-string cr)
      (write-string *sub-note*)
      (write-string cr) )
  (values) )