;;; A Common Lisp implementation of the compo protocol Version 2
;;;
;;; Package :note
;;;
;;; Copyright (C) 2001  Bruno LARTILLOT
;;; 
;;; This program is free software; you can redistribute it and/or
;;; modify it under the terms of the GNU General Public License
;;; as published by the Free Software Foundation; either version 2
;;; of the License, or any later version.
;;;
;;; This program is distributed in the hope that it will be useful,
;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
;;; along with this program; if not, write to the Free Software
;;; Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

(in-package :note)

(proclaim '(special *test-result*))

(setf *test-result* t)
(setf *default-temperament* *compo-temperament*)
(setf *default-syntax* :english)

;;; Test of the cleavep predicate

(when (not (eq (cleavep :treble) :treble))
  (write-string "error on cleavep" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (cleavep :not-a-cleave) nil))
  (write-string "error on cleavep" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

;;; Test of the ntoc function

(when (not (eq (ntoc 0) :treble))
  (write-string "error on ntoc" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (ntoc 10) nil))
  (write-string "error on ntoc" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

;;; Test of the cton function

(when (not (eq (cton :soprano) -1))
  (write-string "error on cton" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (cton :not-a-cleave) :not-a-cleave))
  (write-string "error on cton" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

;;; Test of the function 'ntoev'

(when (not (eq (ntoev 10) -6))
  (write-string "error on ctoev" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

;;; Test of the durationp predicate

(when (not (eq (durationp :q :syntax :english) :q))
  (write-string "error on durationp (1)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (durationp :n :syntax :latin) :n))
  (write-string "error on durationp (2)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (durationp :q :syntax :latin) nil))
  (write-string "error on durationp (3)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (durationp :n) nil))
  (write-string "error on durationp (4)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(setf *default-syntax* :latin)
(when (not (eq (durationp :n.) :n.))
  (write-string "error on durationp (5)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )
(setf *default-syntax* :english)

;;; Test of the ntod function

(when (not (eq (ntod 7/8) :8th..))
  (write-string "error on ntod" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (ntod 11/8) nil))
  (write-string "error on ntod" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (ntod 7/8 :syntax :latin) :c..))
  (write-string "error on ntod" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (ntod 11/8 :syntax :latin) nil))
  (write-string "error on ntod" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(setf *default-syntax* :latin)
(when (not (eq (ntod 7/8) :c..))
  (write-string "error on ntod" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )
(setf *default-syntax* :english)

;;; Test of the dton function

(when (not (eq (dton :dw.) 12))
  (write-string "error on dton" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (dton :dr.) nil))
  (write-string "error on dton" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (dton :dr. :syntax :latin) 12))
  (write-string "error on dton" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (dton :dw. :syntax :latin) nil))
  (write-string "error on dton" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(setf *default-syntax* :latin)
(when (not (eq (dton :dr.) 12))
  (write-string "error on dton" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )
(setf *default-syntax* :english)

;;; Test of the intern-temperament function

(let ((result 
       (cons 35
             (pairlis
              '(:c0 :d0 :e0 :f0 :g0 :a0 :b0
                :cs0 :ds0 :es0 :fs0 :gs0 :as0 :bs0
                :cf0 :df0 :ef0 :ff0 :gf0 :af0 :bf0
                :css0 :dss0 :ess0 :fss0 :gss0 :ass0 :bss0
                :cff0 :dff0 :eff0 :fff0 :gff0 :aff0 :bff0
                
                :c1 :d1 :e1 :f1 :g1 :a1 :b1
                :cs1 :ds1 :es1 :fs1 :gs1 :as1 :bs1
                :cf1 :df1 :ef1 :ff1 :gf1 :af1 :bf1
                :css1 :dss1 :ess1 :fss1 :gss1 :ass1 :bss1
                :cff1 :dff1 :eff1 :fff1 :gff1 :aff1 :bff1
                
                :c2 :d2 :e2 :f2 :g2 :a2 :b2
                :cs2 :ds2 :es2 :fs2 :gs2 :as2 :bs2
                :cf2 :df2 :ef2 :ff2 :gf2 :af2 :bf2
                :css2 :dss2 :ess2 :fss2 :gss2 :ass2 :bss2
                :cff2 :dff2 :eff2 :fff2 :gff2 :aff2 :bff2
                
                :c3 :d3 :e3 :f3 :g3 :a3 :b3
                :cs3 :ds3 :es3 :fs3 :gs3 :as3 :bs3
                :cf3 :df3 :ef3 :ff3 :gf3 :af3 :bf3
                :css3 :dss3 :ess3 :fss3 :gss3 :ass3 :bss3
                :cff3 :dff3 :eff3 :fff3 :gff3 :aff3 :bff3
                
                :c4 :d4 :e4 :f4 :g4 :a4 :b4
                :cs4 :ds4 :es4 :fs4 :gs4 :as4 :bs4
                :cf4 :df4 :ef4 :ff4 :gf4 :af4 :bf4
                :css4 :dss4 :ess4 :fss4 :gss4 :ass4 :bss4
                :cff4 :dff4 :eff4 :fff4 :gff4 :aff4 :bff4
                
                :c5 :d5 :e5 :f5 :g5 :a5 :b5
                :cs5 :ds5 :es5 :fs5 :gs5 :as5 :bs5
                :cf5 :df5 :ef5 :ff5 :gf5 :af5 :bf5
                :css5 :dss5 :ess5 :fss5 :gss5 :ass5 :bss5
                :cff5 :dff5 :eff5 :fff5 :gff5 :aff5 :bff5
                
                :c6 :d6 :e6 :f6 :g6 :a6 :b6
                :cs6 :ds6 :es6 :fs6 :gs6 :as6 :bs6
                :cf6 :df6 :ef6 :ff6 :gf6 :af6 :bf6
                :css6 :dss6 :ess6 :fss6 :gss6 :ass6 :bss6
                :cff6 :dff6 :eff6 :fff6 :gff6 :aff6 :bff6
                
                :c7 :d7 :e7 :f7 :g7 :a7 :b7
                :cs7 :ds7 :es7 :fs7 :gs7 :as7 :bs7
                :cf7 :df7 :ef7 :ff7 :gf7 :af7 :bf7
                :css7 :dss7 :ess7 :fss7 :gss7 :ass7 :bss7
                :cff7 :dff7 :eff7 :fff7 :gff7 :aff7 :bff7
                
                :c8 :d8 :e8 :f8 :g8 :a8 :b8
                :cs8 :ds8 :es8 :fs8 :gs8 :as8 :bs8
                :cf8 :df8 :ef8 :ff8 :gf8 :af8 :bf8
                :css8 :dss8 :ess8 :fss8 :gss8 :ass8 :bss8
                :cff8 :dff8 :eff8 :fff8 :gff8 :aff8 :bff8 )

              '(0 1 2 3 4 5 6 7
                8 9 10 11 12 13 14
                15 16 17 18 19 20 21
                22 23 24 25 26 27 28
                29 30 31 32 33 34 35
                
                36 37 38 39 40 41 42
                43 44 45 46 47 48 49
                50 51 52 53 54 55 56
                57 58 59 60 61 62 63
                64 65 66 67 68 69 70
                
                71 72 73 74 75 76 77
                78 79 80 81 82 83 84
                85 86 87 88 89 90 91
                92 93 94 95 96 97 98
                99 100 101 102 103 104 105
                
                106 107 108 109 110 111 112
                113 114 115 116 117 118 119
                120 121 122 123 124 125 126
                127 128 129 130 131 132 133
                134 135 136 137 138 139 140
                
                141 142 143 144 145 146 147
                148 149 150 151 152 153 154
                155 156 157 158 159 160 161
                162 163 164 165 166 167 168
                169 170 171 172 173 174 175
                
                176 177 178 179 180 181 182
                183 184 185 186 187 188 189
                190 191 192 193 194 195 196
                197 198 199 200 201 202 203
                204 205 206 207 208 209 210
                
                211 212 213 214 215 216 217
                218 219 220 221 222 223 224
                225 226 227 228 229 230 231
                232 233 234 235 236 237 238
                239 240 241 242 243 244 245

                246 247 248 249 250 251 252
                253 254 255 256 257 258 259
                260 261 262 263 264 265 266
                267 268 269 270 271 272 273
                274 275 276 277 278 279 280

                281 282 283 284 285 286 287
                288 289 290 291 292 293 294
                295 296 297 298 299 300 301
                302 303 304 305 306 307 308
                309 310 311 312 313 314 ) ) ) ))

  (when (not (equal (intern-temperament '(35
                                          140 141 142 143 144 145 146 147
                                          148 149 150 151 152 153 154
                                          155 156 157 158 159 160 161
                                          162 163 164 165 166 167 168
                                          169 170 171 172 173 174 ))
                    result ))
    (write-string "error on intern-temperament" *standard-output*)
    (write-string (make-string 1 :initial-element #\newline) *standard-output*)
    (setf *test-result* nil) ) )

;;; Test of the normalize-pitch function

(when (not (eq (normalize-pitch :F4 :syntax :english) :F4))
  (write-string "error on normalize-pitch (1)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (normalize-pitch :F :syntax :english) :F4))
  (write-string "error on normalize-pitch (2)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (normalize-pitch :FA4 :syntax :latin) :FA4))
  (write-string "error on normalize-pitch (3)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (normalize-pitch :FA :syntax :latin) :FA4))
  (write-string "error on normalize-pitch (4)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (normalize-pitch :F4 :syntax :latin) :F4))
  (write-string "error on normalize-pitch (5)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (normalize-pitch :FA4) :FA4))
  (write-string "error on normalize-pitch (6)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (normalize-pitch :ac-bass-drum) :B1))
  (write-string "error on normalize-pitch (7)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (normalize-pitch :side :syntax :latin) :do#2))
  (write-string "error on normalize-pitch (8)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(setf *default-syntax* :latin)
(when (not (eq (normalize-pitch :RE) :RE4))
  (write-string "error on normalize-pitch (9)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (normalize-pitch :bs-drum) :do2))
  (write-string "error on normalize-pitch (10)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )
(setf *default-syntax* :english)

;;; Test of the denormalize-pitch function

(when (not (eq (denormalize-pitch :F4 :syntax :english) :F))
  (write-string "error on denormalize-pitch (1)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (denormalize-pitch :F :syntax :english) :F))
  (write-string "error on denormalize-pitch (2)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (denormalize-pitch :FA4 :syntax :latin) :FA))
  (write-string "error on denormalize-pitch (3)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (denormalize-pitch :FA :syntax :latin) :FA))
  (write-string "error on denormalize-pitch (4)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (denormalize-pitch :F4 :syntax :latin) :F4))
  (write-string "error on denormalize-pitch (5)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (denormalize-pitch :FA4) :FA4))
  (write-string "error on denormalize-pitch (6)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(setf *default-syntax* :latin)
(when (not (eq (denormalize-pitch :FA4) :FA))
  (write-string "error on denormalize-pitch (7)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )
(setf *default-syntax* :english)

;;; Test of the pitchp predicate

(when (not (eq (pitchp :F4 :syntax :english) :F4))
  (write-string "error on pitchp (1)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (pitchp :F :syntax :english) :F4))
  (write-string "error on pitchp (2)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (pitchp :FA4 :syntax :latin) :FA4))
  (write-string "error on pitchp (3)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (pitchp :FA :syntax :latin) :FA4))
  (write-string "error on pitchp (4)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (pitchp :F4 :syntax :latin) nil))
  (write-string "error on pitchp (5)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (pitchp :FA4) nil))
  (write-string "error on pitchp (6)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (pitchp :ac-snare) :d2))
  (write-string "error on pitchp (7)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(setf *default-syntax* :latin)
(when (not (eq (pitchp :mi) :mi4))
  (write-string "error on pitchp (8)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (pitchp :clap) :mib2))
  (write-string "error on pitchp (9)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )
(setf *default-syntax* :english)

;;; Test of the itp function

(when (not (eq (itp 24) :DFF4))
  (write-string "error on itp (1)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (itp 23) nil))
  (write-string "error on itp (2)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (itp 1176 :temperament *pythagorician-temperament*) :DFF4))
  (write-string "error on itp (3)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (itp 24 :syntax :latin) :REBB4))
  (write-string "error on itp (4)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(setf *default-syntax* :latin)
(when (not (eq (itp 24) :REBB4))
  (write-string "error on itp (5)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )
(setf *default-syntax* :english)

;;; Test of the itei function

(when (not (eq (itei -502) 698))
  (write-string "error on itei (1)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (itp -497) nil))
  (write-string "error on itei (2)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (itei -498 :temperament *pythagorician-temperament*) 702))
  (write-string "error on itei (3)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

;;; Test of the itep function

(when (not (eq (itep 2596) :D4))
  (write-string "error on itep (1)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (itp 2605) nil))
  (write-string "error on itep (2)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (itep 2604 :temperament *pythagorician-temperament*) :D4))
  (write-string "error on itep (3)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (itep 2604
                     :temperament *pythagorician-temperament*
                     :syntax :latin ) :RE4))
  (write-string "error on itep (4)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(setf *default-syntax* :latin)
(when (not (eq (itep 2604 :temperament *pythagorician-temperament* ) :RE4))
  (write-string "error on itep (5)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )
(setf *default-syntax* :english)

;;; Test of the pti function

(when (not (eq (pti :FS5) 1788))
  (write-string "error on pti (1)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (pti :D) 196))
  (write-string "error on pti (2)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (pti :FSSS4) nil))
  (write-string "error on pti (3)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (pti :FS5 :temperament *pythagorician-temperament*) 1812))
  (write-string "error on pti (4)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (pti :FA#5 :syntax :latin) 1788))
  (write-string "error on pti (5)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (pti :el-snare) -2008))
  (write-string "error on pti (6)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(setf *default-syntax* :latin)
(when (not (eq (pti :FA#5) 1788))
  (write-string "error on pti (7)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (pti :el-snare) -2008))
  (write-string "error on pti (8)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )
(setf *default-syntax* :english)

;;; Test of the ptep function

(when (not (eq (ptep :AF5) :AF4))
  (write-string "error on ptep (1)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (ptep :H4) nil))
  (write-string "error on ptep (2)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (ptep :AF5
                     :temperament
                     (intern-temperament '(35
                                           0 1 2 3 4 5 6 7
                                           8 9 10 11 12 13 14
                                           15 16 17 18 19 20 21
                                           22 23 24 25 26 27 28
                                           29 30 31 32 33 34 )) )
               :AF4 ))
  (write-string "error on ptep (3)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (ptep :LAB5 :syntax :latin) :LAB4))
  (write-string "error on ptep (4)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (ptep :lo-floor-tom) :F4))
  (write-string "error on ptep (5)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(setf *default-syntax* :latin)
(when (not (eq (ptep :LAB5) :LAB4))
  (write-string "error on ptep (6)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (eq (ptep :lo-floor-tom) :FA4))
  (write-string "error on ptep (7)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )
(setf *default-syntax* :english)

;;; Test of the naturalp function

(when (not (naturalp :C4))
  (write-string "error on naturalp" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (naturalp :CS4)
  (write-string "error on naturalp" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (naturalp :DO4 :syntax :latin))
  (write-string "error on naturalp" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(setf *default-syntax* :latin)
(when (not (naturalp :DO4))
  (write-string "error on naturalp" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )
(setf *default-syntax* :english)

;;; Test of the sharpp function

(when (not (sharpp :DS4))
  (write-string "error on sharpp" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (sharpp :DF4)
  (write-string "error on sharpp" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (sharpp :RE#4 :syntax :latin))
  (write-string "error on sharpp" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(setf *default-syntax* :latin)
(when (not (sharpp :RE#4))
  (write-string "error on sharpp" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )
(setf *default-syntax* :english)

;;; Test of the flatp function

(when (not (flatp :EF4))
  (write-string "error on flatp" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (flatp :ESS4)
  (write-string "error on flatp" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (flatp :MiB4 :syntax :latin))
  (write-string "error on flatp" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(setf *default-syntax* :latin)
(when (not (flatp :MiB4))
  (write-string "error on flatp" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )
(setf *default-syntax* :english)

;;; Test of the double-sharp-p function

(when (not (double-sharp-p :FSS7))
  (write-string "error on double-sharp-p" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (double-sharp-p :FS2)
  (write-string "error on double-sharp-p" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (double-sharp-p :FA##7 :syntax :latin))
  (write-string "error on double-sharp-p" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(setf *default-syntax* :latin)
(when (not (double-sharp-p :FA##7))
  (write-string "error on double-sharp-p" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )
(setf *default-syntax* :english)

;;; Test of the double-sharp-p function

(when (not (double-flat-p :GFF8))
  (write-string "error on double-flat-p" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (double-flat-p :G1)
  (write-string "error on double-flat-p" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (double-flat-p :SOLbb8 :syntax :latin))
  (write-string "error on double-flat-p" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(setf *default-syntax* :latin)
(when (not (double-flat-p :SOLbb8))
  (write-string "error on double-flat-p" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )
(setf *default-syntax* :english)

;;; test of the macro 'sugar-note'

(sugar-note test note
            :hei :d4
            :dur (* prev-dur :h)
            :pos-mod :super
            :pos 2
            :voi :bass
            :dyn 1/2
            :temperament *equal-temperament* )

(when (not (is-equal (test ()(:hei :e4))
                     (note :hei 200
                           :dur (* prev-dur :h)
                           :pos-mod :super
                           :pos 2
                           :bass
                           :dyn 1/2
                           (note :hei 200
                                 :dur (* prev-dur :h)
                                 :pos-mod :super
                                 :pos 2
                                 :bass
                                 :dyn 1/2 )
                           (note :hei 400
                                 :dur (* prev-dur :h)
                                 :pos-mod :super
                                 :pos 2
                                 :bass
                                 :dyn 1/2 ) ) ))
  (write-string "error on (is-equal note note)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(setf *default-syntax* :latin)
(sugar-note test note
            :hei :re4
            :dur (* prev-dur :b)
            :pos-mod :super
            :pos 2
            :voi :bass
            :dyn 1/2
            :temperament *equal-temperament* )

(when (not (is-equal (test ()(:hei :mi4))
                     (note :hei 200
                           :dur (* prev-dur :b)
                           :pos-mod :super
                           :pos 2
                           :bass
                           :dyn 1/2
                           (note :hei 200
                                 :dur (* prev-dur :b)
                                 :pos-mod :super
                                 :pos 2
                                 :bass
                                 :dyn 1/2 )
                           (note :hei 400
                                 :dur (* prev-dur :b)
                                 :pos-mod :super
                                 :pos 2
                                 :bass
                                 :dyn 1/2 ) ) ))
  (write-string "error on (is-equal note note)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )
(setf *default-syntax* :english)

(when (not (is-equal (note :D4 :pos 1 :dur :h :bass :dyn 2 (note :E4))
                     (note :D4 :pos 1 :dur :h :bass :dyn 2 (note :E4)) ))
  (write-string "error on (is-equal note note)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(setf *default-syntax* :latin)
(let ((test (note :RE4 :pos 1 :dur :b :bass :dyn 2 (note :dur :b.))))
  (when (not (is-equal test (clone test)))
    (write-string "error on (is-equal note (clone note))" *standard-output*)
    (write-string (make-string 1 :initial-element #\newline) *standard-output*)
    (setf *test-result* nil) ) )
(setf *default-syntax* :english)

(when (is-equal (note :hei :E4)
                (note :hei :E4 (note)) )
  (write-string "error on (not (is-equal note (note :subs (note))))" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(let ((test (note :alto)))
  (setf (subs (clone test)) (list (note)))
  (when (not (is-equal test (note :alto)))
    (write-string "error on (clone note)" *standard-output*)
    (write-string (make-string 1 :initial-element #\newline) *standard-output*)
    (setf *test-result* nil) ) )

;;; test of the mode coercion specifier

(when (not (= (mode 204 100 200 300 400) 200))
  (write-string "error on mode" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (= (mode 1404 100 200 300 400) 1400))
  (write-string "error on mode" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (= (mode 1200 100 200 300 400) 1300))
  (write-string "error on mode" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

;;; test of the cnote constructor

(when (not (= (pos (cnote :pos-mod :abs)) 0))
  (write-string "error on cnote" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

;;; test of the compo-lessp comparator specialized on note

(when (not (compo-lessp (note :D4 :pos 1 :dur :h :voi 10 :dyn 2 (note :E4))
                        (note :D4 :pos 1 :dur :h :tenor :dyn 2 (note :E4)) ))
  (write-string "error on compo-lessp (1)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (compo-lessp (note :D4 :pos 1 :dur :h :bass :dyn 2 (note :E4))
                        (note :D4 :pos 1 :dur :h :tenor :dyn 2 (note :E4)) ))
  (write-string "error on compo-lessp (2)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (compo-lessp (note :D4 :pos-mod :abs :pos 1 :dur :h :bass :dyn 2 (note :E4))
                        (note :D4 :pos-mod :abs :pos 2 :dur :h :bass :dyn 2 (note :E4)) ))
  (write-string "error on compo-lessp (3)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (compo-lessp (note :D4 :pos-mod :abs :pos 1 :dur :h :bass :dyn 2 (note :E4))
                        (note :E4 :pos-mod :abs :pos 1 :dur :h :bass :dyn 2 (note :E4)) ))
  (write-string "error on compo-lessp (4)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

;;; test of the atomization context-item

(when (not (is-equal (realize-using-context-item
                      (atomization)
                      (compo (compo) (() ())) )
                     (compo (compo) (compo) (compo)) ))
    (write-string "error on atomization" *standard-output*)
    (write-string (make-string 1 :initial-element #\newline) *standard-output*)
    (setf *test-result* nil) )

(when (not (is-equal (realize-using-context-item
                      (atomization)
                      (compo) )
                     (compo) ))
    (write-string "error on atomization" *standard-output*)
    (write-string (make-string 1 :initial-element #\newline) *standard-output*)
    (setf *test-result* nil) )

;;; test of the coercion context-item along with coerce-compo specialized on note

(when (not (is-equal (realize-using-context-item
                      (coercion)
                      (note
                       :coerce-hei '(mode :D4 :G4)
                       :coerce-pos '(integer 2 3)
                       :coerce-dur '(integer :q :w)
                       :coerce-voi '(integer :alto :treble)
                       :coerce-dyn '(integer 1 2)
                       (note :hei :E4 :pos-mod :abs :pos 2 :dur :w :voi :bass)
                       (note :hei :E4 :pos-mod :abs :pos 4 :dur :w :voi :alto)
                       (note :hei :E4 :pos-mod :abs :pos 2 :dur :8th :voi :alto)
                       (note :hei :E4 :pos-mod :abs :pos 2 :dur :w :voi :alto :dyn 3/2)
                       (note :hei :E4 :pos-mod :abs :pos 2 :dur :w :voi :alto) ) )
                     (note
                      :coerce-hei '(mode :D4 :G4)
                      :coerce-pos '(integer 2 3)
                      :coerce-dur '(integer :q :w)
                      :coerce-voi '(integer :alto :treble)
                      :coerce-dyn '(integer 1 2)
                      (note :hei :D4 :pos-mod :abs :pos 2 :dur :w :voi :alto) ) ))
  (write-string "error on coercion" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

;;; test of the evaluation context-item along with evaluate specialized on note

(when (not (is-equal (realize-using-context-item
                      (evaluation)
                      (make-instance 'note
                                     :voi 'super-voi
                                     :dur '((* prev-dur) super-dur)
                                     :pos-mod :juxt
                                     :hei `'(mode (+ ,(pti :D4) super-hei))
                                     :dyn ''((integer (* 2 prev-dyn)) super-dyn) )
                      :prev-compo (note :pos-mod :abs :pos 2 :h. :dyn 2)
                      :super-compo (note :F4 :alto :8th :dyn 1/2) )
                     (make-instance 'note
                                    :hei `'(mode ,(pti :G4))
                                    :dur (dton :q.) 
                                    :pos 5
                                    :voi (cton :alto)
                                    :dyn ''(integer 4 1/2) ) ))
  (write-string "error on evaluation" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

;;; test of the granulation context-item

(when (not (is-equal (realize-using-context-item
                      (granulation)
                      (compo (compo))
                      :depth 0 )
                     (compo) ))
  (write-string "error on granulation" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (is-equal (realize-using-context-item
                      (granulation)
                      (compo (compo))
                      :depth 2 )
                     (compo (compo)) ))
  (write-string "error on granulation" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (is-equal (realize-using-context-item
                      (granulation)
                      (compo (compo)) )
                     (compo (compo)) ))
  (write-string "error on granulation" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

;;; test of the integration context-item along with the integrate-compo generic-function

(when (not (is-equal (realize-using-context-item
                      (integration)
                      (note (note :q. :pos-mod :abs :pos 2)
                            (note :w :pos-mod :abs :pos 3) ) )
                     (note :dur 5 :pos-mod :abs :pos 2
                           (note :q. :pos-mod :abs :pos 2)
                           (note :w :pos-mod :abs :pos 3) ) ))
  (write-string "error on integration" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

;;; test of the realization context-item

(when (not (is-equal (realize-using-context-item
                      (make-instance 'realization
                       :context (atomization) )
                      (compo (())) )
                     (compo ()) ))
  (write-string "error on realization" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

;;; test of the recursion context-item

(let ((test (realize-using-context-item
                      (recursion :subs (atomization))
                      (compo (compo (compo "1")
                                    (compo 
                                     (compo
                                      (compo "2")
                                      (compo "3")
                                      (compo "4") ) ) )) )))
  (when (not (is-equal test (compo (compo (compo :name "1")
                                          (compo (compo "2")
                                                 (compo "3")
                                                 (compo "4") ) ))))
    (write-string "error on recursion" *standard-output*)
    (write-string (make-string 1 :initial-element #\newline) *standard-output*)
    (setf *test-result* nil) ) )

(when (not (is-equal (realize-using-context-item
                      (recursion)
                      (compo (compo) (compo)) )
                     (compo (compo) (compo)) ))
  (write-string "error on recursion" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

;;; test of the sorting context-item

(when (not (is-equal (realize-using-context-item
                      (sorting)
                      (note (note :D4 :pos-mod :abs :pos 1 :bass)
                            (note :pos-mod :abs :pos 2 :treble)
                            (note :pos-mod :abs :pos 0 :bass)
                            (note :pos-mod :abs :pos 1 :bass) ) )
                     (note (note :pos-mod :abs :pos 0 :bass)
                           (note :pos-mod :abs :pos 1 :bass)
                           (note :pos-mod :abs :D4 :pos 1 :bass)
                           (note :pos-mod :abs :pos 2 :treble) ) ))
  (write-string "error on sorting" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

;;; test of the transformation context-item along with the transform generic function

(when (not (is-equal (realize-using-context-item
                      (transformation)
                      (make-instance 'note
                        :hei (pti :F4)
                        :dur `(+ ,(dton :h) 3)
                        :pos ''(integer 2 3)
                        :voi `'((integer ,(cton :alto))
                                '(rational ,(cton :tenor)) )
                        :dyn '(+ (* 3 prev-dyn) 2) )
                      :super-compo (note :D4
                                         :8th
                                         :pos 2
                                         :soprano
                                         :dyn 2) )
                     (make-instance 'note
                       :hei `(+ ,(pti :F4) ,(pti :D4))
                       :dur `(+ (* ,(dton :h) ,(dton :8th)) (* ,(dton :h.) ,(dton :8th)))
                       :pos ''(integer (* 2 1/2) (* 3 1/2))
                       :voi `'((integer ,(cton :alto))
                               '(rational (+ ,(cton :tenor) ,(cton :soprano))) )
                       :dyn '(+ (* (* 3 2) (* prev-dyn 2)) (* 2 2)) ) ))
  (write-string "error on transformation" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

;;; test of the unicity context-item

(when (not (is-equal (realize-using-context-item
                      (unicity)
                      (compo (compo "a")
                             (compo "b")
                             (compo "a") ) )
                     (compo (compo "a")
                            (compo "b") ) ))
  (write-string "error on unicity" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (is-equal (realize-using-context-item
                      (unicity)
                      (compo) )
                     (compo) ))
  (write-string "error on unicity" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

;;; test of the realize function applied on a note

(when (not (is-equal (realize
                      (note
                       :D4
                       :coerce-pos '(rational 0 4)
                       (note :FS4 :pos-mod :abs :pos 3)
                       (note :D4 :pos 1)
                       (note :D4 :pos 2
                             (note :D4 :pos-mod :super :pos -4)
                             (note :E4) ) ) )
                     (cnote :h :pos-mod :abs :pos 3
                            :coerce-pos '(rational 0 4)
                            (note :GS4 :pos-mod :abs :pos 3)
                            (note :FS4 :pos-mod :abs :pos 4) ) ))
  (write-string "error on realize (1)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(setf note
      (note :D4
            (note :FS4 :abs :pos 3)
            (note :D4 :abs :pos 1)
            (note :D4 :abs :pos 2
                  (note :D4 :abs :pos 0)
                  (note :E4) ) ) )

(setf context (make-instance 'standard-context))

(setf save-note (clone note))

(setf save-context (clone context))

(setf result (cnote :w :abs :pos 0
                    (note :E4 :h :abs :pos 0)
                    (note :E4 :abs :pos 1)
                    (note :GS4 :abs :pos 3) ))

(when (not (is-equal (realize note :context context :depth 1) result))
  (write-string "error on realize (2)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (is-equal (realize note :depth 1) result))
  (write-string "error on realize (3)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (is-equal note save-note))
  (write-string "error on realize (4)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (is-equal context save-context))
  (write-string "error on realize (5)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (is-equal (realize
                      (note
                       :D4
                       (:hei nil :dur :h)
                       (:D4) ) )
                     (cnote :abs :pos 2 (note :E4 :abs :pos 2)) ))
  (write-string "error on realize (6)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (is-equal (realize (note (:d)(lyrics :e "a")))
                     (cnote :abs :pos 0 (note :d :abs :pos 0)) ))
  (write-string "error on realize (7)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (is-equal (realize (note (:d)(:e "a")) :preserve-lyrics t)
                     (cnote :h :abs :pos 0
                            (note :d :abs :pos 0)
                            (note "a" :e :abs :pos 1) ) ))
  (write-string "error on realize (8)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(setf *default-syntax* :latin)
(when (not (is-equal (realize
                      (note
                       :RE4
                       (:hei nil :dur :b)
                       (:RE4) ) )
                     (cnote :abs :pos 2 (note :MI4 :abs :pos 2)) ))
  (write-string "error on realize (9)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )
(setf *default-syntax* :english)

;;; test of the class 'cnote'

(setf cnote
      (cnote :w :abs :pos 0
             (note :E4 :h :abs :pos 0)
             (note :E4 :abs :pos 1)
             (note :GS4 :abs :pos 3) ) )

(when (not (is-equal (realize cnote) cnote))
  (write-string "error on cnote (1)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (is-equal (realize cnote) (realize (realize cnote))))
  (write-string "error on cnote (2)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

;;; test of the class 'fermata'

(when (not (is-equal (realize
                      (note ((fermata))))
                     (cnote :abs (fermata :abs)) ))
  (write-string "error on fermata" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

;;; test of the class 'repeat-end'

(when (not (is-equal (realize
                      (note ((repeat-end))))
                     (cnote :abs (repeat-end :abs)) ))
  (write-string "error on repeat-end" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

;;; test of the class 'fermata-repeat-end'

(when (not (is-equal (realize
                      (note ((fermata-repeat-end))))
                     (cnote :abs (fermata-repeat-end :abs)) ))
  (write-string "error on repeat-end" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

;;; test of the class 'lyrics'

(when (not (is-equal (realize
                      (note (lyrics ("a"))) :preserve-lyrics t)
                     (cnote :abs (note "a" :abs))) )
  (write-string "error on lyrics (1)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

(when (not (is-equal (realize
                      (note (lyrics ("a"))))
                     (cnote :abs) ))
  (write-string "error on lyrics (2)" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

;;; Test of the full counterpoint sample

(unless
  (is-equal
   (realize
    (note "Realization" :bf3 :8th :pos-mod :abs :pos 1
          modele=(note "modele"
                       :pos-mod :super
                       (:E4)
                       (:A4)
                       (:E4 :8th)
                       (:FS4 :8th)
                       (:E4 :q.)
                       (:D4 :8th)
                       (:CS4 :8th)
                       (:B3 :8th)
                       (:CS4 :8th)
                       (:D4 :8th)
                       (:E4)
                       (:GS3)
                       (:FS3 :8th :pos 3/2)
                       (:GS3 :8th)
                       (:A3 :8th)
                       (:B3)
                       (:E4 :q.)
                       (:D4)
                       (:CS4 :8th)
                       (:B3)
                       (:GS3)
                       (:A3 :8th)
                       (:B3 :8th)
                       (:CS4 :8th :pos 1/2)
                       (:D4 :q.)
                       (:E4 :8th)
                       (:CS4 :8th)
                       (:D4 :8th)
                       (:E4)
                       (:FS4 :8th)
                       (:D4 :8th)
                       (:B3)
                       (:E4)
                       (:D4)
                       (:B3)
                       (:A3 :h.) )
          (:C5 :soprano :pos-mod :super :pos 12
               :coerce-pos '(rational 0 (list 57/2))
               (:coerce-hei '((mode :c :d :ef :fs :g :a :bf))
                            modele ) )
          (:soprano ("fin soprano"
                     (:a4)
                     (:b4 :8th)
                     (:gs4)
                     (:a4 :h.) ))
          (:alto :pos-mod :super :pos 8
                 :coerce-pos '(rational 0 (list 28))
                 (:coerce-hei '((mode :c :d :ef :fs :g :a :bf))
                              modele ) )
          (:alto ("fin alto"
                  (:a3)
                  (:fs4)
                  (:e4 :8th)
                  (:d4 :8th)
                  (:cs4 :h.) ))
          (:tenor :pos-mod :super
                  (:coerce-hei '((mode :c :d :ef :fs :g :a :bf))
                               modele ) )
          (:C3 :bass :pos-mod :super :pos 4
               :coerce-pos '(rational 0 (list 28))
               (:coerce-hei '((mode :c :d :ef :fs :g :a :bf))
                         modele ) )
          (:bass ("fin bass"
                  (:cs3)
                  (:b2)
                  (:e3)
                  (:a2 :h.) )) ) )
   (CNOTE "Realization" :DUR 16 :POS-MOD :ABS :POS 1
          (NOTE :D3 :8TH :POS-MOD :ABS :POS 3 :BASS)
          (NOTE :G3 :8TH :POS-MOD :ABS :POS 7/2 :BASS)
          (NOTE :D3 :16TH :POS-MOD :ABS :POS 4 :BASS)
          (NOTE :EF3 :16TH :POS-MOD :ABS :POS 17/4 :BASS)
          (NOTE :D3 :8TH. :POS-MOD :ABS :POS 9/2 :BASS)
          (NOTE :C3 :16TH :POS-MOD :ABS :POS 21/4 :BASS)
          (NOTE :BF2 :16TH :POS-MOD :ABS :POS 11/2 :BASS)
          (NOTE :A2 :16TH :POS-MOD :ABS :POS 23/4 :BASS)
          (NOTE :BF2 :16TH :POS-MOD :ABS :POS 6 :BASS)
          (NOTE :C3 :16TH :POS-MOD :ABS :POS 25/4 :BASS)
          (NOTE :D3 :8TH :POS-MOD :ABS :POS 13/2 :BASS)
          (NOTE :FS2 :8TH :POS-MOD :ABS :POS 7 :BASS)
          (NOTE :EF2 :16TH :POS-MOD :ABS :POS 33/4 :BASS)
          (NOTE :FS2 :16TH :POS-MOD :ABS :POS 17/2 :BASS)
          (NOTE :G2 :16TH :POS-MOD :ABS :POS 35/4 :BASS)
          (NOTE :A2 :8TH :POS-MOD :ABS :POS 9 :BASS)
          (NOTE :D3 :8TH. :POS-MOD :ABS :POS 19/2 :BASS)
          (NOTE :C3 :8TH :POS-MOD :ABS :POS 41/4 :BASS)
          (NOTE :BF2 :16TH :POS-MOD :ABS :POS 43/4 :BASS)
          (NOTE :A2 :8TH :POS-MOD :ABS :POS 11 :BASS)
          (NOTE :FS2 :8TH :POS-MOD :ABS :POS 23/2 :BASS)
          (NOTE :G2 :16TH :POS-MOD :ABS :POS 12 :BASS)
          (NOTE :A2 :16TH :POS-MOD :ABS :POS 49/4 :BASS)
          (NOTE :BF2 :16TH :POS-MOD :ABS :POS 51/4 :BASS)
          (NOTE :C3 :8TH. :POS-MOD :ABS :POS 13 :BASS)
          (NOTE :D3 :16TH :POS-MOD :ABS :POS 55/4 :BASS)
          (NOTE :B2 :8TH :POS-MOD :ABS :POS 14 :BASS)
          (NOTE :A2 :8TH :POS-MOD :ABS :POS 29/2 :BASS)
          (NOTE :D3 :8TH :POS-MOD :ABS :POS 15 :BASS)
          (NOTE :G2 :Q. :POS-MOD :ABS :POS 31/2 :BASS)
          (NOTE :D4 :8TH :POS-MOD :ABS :POS 1 :TENOR)
          (NOTE :G4 :8TH :POS-MOD :ABS :POS 3/2 :TENOR)
          (NOTE :D4 :16TH :POS-MOD :ABS :POS 2 :TENOR)
          (NOTE :EF4 :16TH :POS-MOD :ABS :POS 9/4 :TENOR)
          (NOTE :D4 :8TH. :POS-MOD :ABS :POS 5/2 :TENOR)
          (NOTE :C4 :16TH :POS-MOD :ABS :POS 13/4 :TENOR)
          (NOTE :BF3 :16TH :POS-MOD :ABS :POS 7/2 :TENOR)
          (NOTE :A3 :16TH :POS-MOD :ABS :POS 15/4 :TENOR)
          (NOTE :BF3 :16TH :POS-MOD :ABS :POS 4 :TENOR)
          (NOTE :C4 :16TH :POS-MOD :ABS :POS 17/4 :TENOR)
          (NOTE :D4 :8TH :POS-MOD :ABS :POS 9/2 :TENOR)
          (NOTE :FS3 :8TH :POS-MOD :ABS :POS 5 :TENOR)
          (NOTE :EF3 :16TH :POS-MOD :ABS :POS 25/4 :TENOR)
          (NOTE :FS3 :16TH :POS-MOD :ABS :POS 13/2 :TENOR)
          (NOTE :G3 :16TH :POS-MOD :ABS :POS 27/4 :TENOR)
          (NOTE :A3 :8TH :POS-MOD :ABS :POS 7 :TENOR)
          (NOTE :D4 :8TH. :POS-MOD :ABS :POS 15/2 :TENOR)
          (NOTE :C4 :8TH :POS-MOD :ABS :POS 33/4 :TENOR)
          (NOTE :BF3 :16TH :POS-MOD :ABS :POS 35/4 :TENOR)
          (NOTE :A3 :8TH :POS-MOD :ABS :POS 9 :TENOR)
          (NOTE :FS3 :8TH :POS-MOD :ABS :POS 19/2 :TENOR)
          (NOTE :G3 :16TH :POS-MOD :ABS :POS 10 :TENOR)
          (NOTE :A3 :16TH :POS-MOD :ABS :POS 41/4 :TENOR)
          (NOTE :BF3 :16TH :POS-MOD :ABS :POS 43/4 :TENOR)
          (NOTE :C4 :8TH. :POS-MOD :ABS :POS 11 :TENOR)
          (NOTE :D4 :16TH :POS-MOD :ABS :POS 47/4 :TENOR)
          (NOTE :BF3 :16TH :POS-MOD :ABS :POS 12 :TENOR)
          (NOTE :C4 :16TH :POS-MOD :ABS :POS 49/4 :TENOR)
          (NOTE :D4 :8TH :POS-MOD :ABS :POS 25/2 :TENOR)
          (NOTE :EF4 :16TH :POS-MOD :ABS :POS 13 :TENOR)
          (NOTE :C4 :16TH :POS-MOD :ABS :POS 53/4 :TENOR)
          (NOTE :A3 :8TH :POS-MOD :ABS :POS 27/2 :TENOR)
          (NOTE :D4 :8TH :POS-MOD :ABS :POS 14 :TENOR)
          (NOTE :C4 :8TH :POS-MOD :ABS :POS 29/2 :TENOR)
          (NOTE :A3 :8TH :POS-MOD :ABS :POS 15 :TENOR)
          (NOTE :G3 :Q. :POS-MOD :ABS :POS 31/2 :TENOR)
          (NOTE :D4 :8TH :POS-MOD :ABS :POS 5 :ALTO)
          (NOTE :G4 :8TH :POS-MOD :ABS :POS 11/2 :ALTO)
          (NOTE :D4 :16TH :POS-MOD :ABS :POS 6 :ALTO)
          (NOTE :EF4 :16TH :POS-MOD :ABS :POS 25/4 :ALTO)
          (NOTE :D4 :8TH. :POS-MOD :ABS :POS 13/2 :ALTO)
          (NOTE :C4 :16TH :POS-MOD :ABS :POS 29/4 :ALTO)
          (NOTE :BF3 :16TH :POS-MOD :ABS :POS 15/2 :ALTO)
          (NOTE :A3 :16TH :POS-MOD :ABS :POS 31/4 :ALTO)
          (NOTE :BF3 :16TH :POS-MOD :ABS :POS 8 :ALTO)
          (NOTE :C4 :16TH :POS-MOD :ABS :POS 33/4 :ALTO)
          (NOTE :D4 :8TH :POS-MOD :ABS :POS 17/2 :ALTO)
          (NOTE :FS3 :8TH :POS-MOD :ABS :POS 9 :ALTO)
          (NOTE :EF3 :16TH :POS-MOD :ABS :POS 41/4 :ALTO)
          (NOTE :FS3 :16TH :POS-MOD :ABS :POS 21/2 :ALTO)
          (NOTE :G3 :16TH :POS-MOD :ABS :POS 43/4 :ALTO)
          (NOTE :A3 :8TH :POS-MOD :ABS :POS 11 :ALTO)
          (NOTE :D4 :8TH. :POS-MOD :ABS :POS 23/2 :ALTO)
          (NOTE :C4 :8TH :POS-MOD :ABS :POS 49/4 :ALTO)
          (NOTE :BF3 :16TH :POS-MOD :ABS :POS 51/4 :ALTO)
          (NOTE :A3 :8TH :POS-MOD :ABS :POS 13 :ALTO)
          (NOTE :FS3 :8TH :POS-MOD :ABS :POS 27/2 :ALTO)
          (NOTE :G3 :8TH :POS-MOD :ABS :POS 14 :ALTO)
          (NOTE :E4 :8TH :POS-MOD :ABS :POS 29/2 :ALTO)
          (NOTE :D4 :16TH :POS-MOD :ABS :POS 15 :ALTO)
          (NOTE :C4 :16TH :POS-MOD :ABS :POS 61/4 :ALTO)
          (NOTE :B3 :Q. :POS-MOD :ABS :POS 31/2 :ALTO)
          (NOTE :D5 :8TH :POS-MOD :ABS :POS 7 :SOPRANO)
          (NOTE :G5 :8TH :POS-MOD :ABS :POS 15/2 :SOPRANO)
          (NOTE :D5 :16TH :POS-MOD :ABS :POS 8 :SOPRANO)
          (NOTE :EF5 :16TH :POS-MOD :ABS :POS 33/4 :SOPRANO)
          (NOTE :D5 :8TH. :POS-MOD :ABS :POS 17/2 :SOPRANO)
          (NOTE :C5 :16TH :POS-MOD :ABS :POS 37/4 :SOPRANO)
          (NOTE :BF4 :16TH :POS-MOD :ABS :POS 19/2 :SOPRANO)
          (NOTE :A4 :16TH :POS-MOD :ABS :POS 39/4 :SOPRANO)
          (NOTE :BF4 :16TH :POS-MOD :ABS :POS 10 :SOPRANO)
          (NOTE :C5 :16TH :POS-MOD :ABS :POS 41/4 :SOPRANO)
          (NOTE :D5 :8TH :POS-MOD :ABS :POS 21/2 :SOPRANO)
          (NOTE :FS4 :8TH :POS-MOD :ABS :POS 11 :SOPRANO)
          (NOTE :EF4 :16TH :POS-MOD :ABS :POS 49/4 :SOPRANO)
          (NOTE :FS4 :16TH :POS-MOD :ABS :POS 25/2 :SOPRANO)
          (NOTE :G4 :16TH :POS-MOD :ABS :POS 51/4 :SOPRANO)
          (NOTE :A4 :8TH :POS-MOD :ABS :POS 13 :SOPRANO)
          (NOTE :D5 :8TH. :POS-MOD :ABS :POS 27/2 :SOPRANO)
          (NOTE :G4 :8TH :POS-MOD :ABS :POS 57/4 :SOPRANO)
          (NOTE :A4 :16TH :POS-MOD :ABS :POS 59/4 :SOPRANO)
          (NOTE :FS4 :8TH :POS-MOD :ABS :POS 15 :SOPRANO)
          (NOTE :G4 :Q. :POS-MOD :ABS :POS 31/2 :SOPRANO)) )
  (write-string "error on counterpoint sample" *standard-output*)
  (write-string (make-string 1 :initial-element #\newline) *standard-output*)
  (setf *test-result* nil) )

;;; End of test

(if *test-result*
  (progn
    (write-string "test ok :note" *standard-output*)
    (write-string (make-string 1 :initial-element #\newline) *standard-output*) )
  (progn
    (write-string "test not ok :note" *standard-output*)
    (write-string (make-string 1 :initial-element #\newline) *standard-output*) ) )